
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
IBAN module of the Python FinTech package.

This module defines functions to check and create IBANs.
"""

__all__ = ['check_iban', 'create_iban', 'check_bic', 'get_bic', 'parse_iban', 'get_bankname']


def check_iban(iban, bic=None, country=None, sepa=False):
    """
    Checks an IBAN for validity.

    If the *kontocheck* package is available, for German IBANs the
    bank code and the checksum of the account number are checked as
    well.

    :param iban: The IBAN to be checked.
    :param bic: If given, IBAN and BIC are checked in the
        context of each other.
    :param country: If given, the IBAN is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param sepa: If *sepa* evaluates to ``True``, the IBAN is
        checked to be valid in the Single Euro Payments Area.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    pass


def create_iban(bankcode, account, bic=False):
    """
    Creates an IBAN from a German bank code and account number.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.

    :param bankcode: The German bank code.
    :param account: The account number.
    :param bic: Flag if the corresponding BIC should be returned as well.
    :returns: Either the IBAN or a 2-tuple in the form of (IBAN, BIC).
    """
    pass


def check_bic(bic, country=None, scl=False):
    """
    Checks a BIC for validity.

    :param bic: The BIC to be checked.
    :param country: If given, the BIC is checked in the
        context of this country. Must be an ISO-3166 ALPHA 2
        code.
    :param scl: If set to ``True``, the BIC is checked for occurrence
        in the SEPA Clearing Directory, published by the German Central
        Bank. If set to a value of *SCT*, *SDD*, *COR1*, or *B2B*, *SCC*,
        the BIC is also checked to be valid for this payment order type.
        The *kontocheck* package is required for this option.
        Otherwise a *RuntimeError* is raised.
    :returns: ``True`` on validity, ``False`` otherwise.
    """
    pass


def get_bic(iban):
    """
    Returns the corresponding BIC for a given German IBAN.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    pass


def parse_iban(iban):
    """
    Splits a given IBAN into its fragments.

    Returns a 4-tuple in the form of
    (COUNTRY, CHECKSUM, BANK_CODE, ACCOUNT_NUMBER)
    """
    pass


def get_bankname(iban_or_bic):
    """
    Returns the bank name of a given German IBAN or European BIC.
    In the latter case the bank name is read from the SEPA Clearing
    Directory published by the German Central Bank.

    The *kontocheck* package is required to perform this function.
    Otherwise a *RuntimeError* is raised.
    """
    pass



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x020\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds\xd2)\x00\x00PYARMOR\x00\x00\x03\t\x00a\r\r'
        b'\n\t0\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\x92)\x00\x00\x00\x00\x00\x002\x02\x89H\xab\xda\xcb\x83Zk\x86\x10\x8c\x18/c\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2a0\x8e\xc4\xaa?\xe0\xcfg\x9d\xb68\x18\x82\xad\x8f\xc8\x00\x98\xc7\x1f\x92bM\xf0\x12=\x0c\x9d\xec\x0c\xf8\xfa\x1a:\xf0\xbc\tLk|1\r\xde\xea\xa2"\x97@\x85+Kl'
        b'M>\xe7\xae\xb8\x0f\xdd+\xbd"\xba\xbd\xeb\x04\xc0\x84%Q\xb5\ts\x98\x03\xdb"\xca\xf7\xa9\xfa\x840\x17\xd8\xb5(\x08\xd0\x89c_g"\x81\x8a\xfa\xc7\xb2\x97\xae\x15\x12\x1b\xb8D\xbf0\xe1+;Q\x13/\x17\xf5'
        b'\xb05)\x02\xfaNd\x88\xc9zyI\xb4u\xef\xfc:\x1f.D\rC\x1a|\xd5Fa\x8b\xd3\x08\xbb\xa8KA7H\xf1\x0f\x0b\x95mNk\xb7\xb9\xc6F 3LV\x15\x1b\xec\xb2\xab\xbb\x06\x8e\x9f$\x81\x90<'
        b'u\xdb\xd5\x03\x07\xb8\xed\x97|}O|\xfc\xb6\x94\x81\x0b\x9f\xef\xaa\xd9\xb7(E[\xbc\x99\x10\xd1\\\xffUZ\xea\x94\x85\xf8W\x8b}\xd8\xd0\xcdl\xc66\xf2M\x9e:\x92\xb3\x07\x08\xf6O~C\xa3\xfea\x8c\xf9\x1e'
        b'\xc7\xdc\xaa\xe3\x0e \x86"8\xbc\xa3:1=\x14;e~L\xf9p\x9f\xe5(3\xd2\xf7\x00Z72\x9d-.\xef_\xdc`)\r\x89\x13\x10\xd4\xf1\x0b7\xff\xb2:\x82\x87=%\xcdC-|\xcb\xdc\x90\xb1\xefo'
        b'\x00\x1f;\xf7A\xd4\x94\xa4$\xee\x92I9\ra\x0f\x1d\xc1\x1c\x98\xb8u\x897\xf5e\x91\x9d\xa2\xdfs\xe1\xac\x94\xa3\xcc"\xd9\xfd\xe7DC\xc9?\x05\xb6\x11\xc2E(X\x1e\xeb\xbc\x01L\x8a\xff\xd1\xd1\x9dB`U'
        b'\x94\x02N\xae\x93\xeb\x89\xc1\xab\xfeK\xf3\xf4\xe5\xd8\xc8\x07S\xd2\xe3n\x1b<\x8d\xf0\x1f?I\xb4\x11\x0c\xd6&0\xce>\xa4\xce\x9bZ\xdfUY#A\xa0\xbc\x0c\xcf\xd8\xcc\x1e\xd9b\xd9\x07\x11GsX \xce\x87\x95'
        b"\xdb\xbe,\xfe\xf4\x8d\xfd\x82,\xb1\xb8uj\t\x03\xb4\xdcv\x05F\xf2\xd9\xd3\x8d\x94\x12\xa70a\xc2\x02\xda\x1a\xe1j\xe4`GtQ\xaf\x8dC\x97\xc0\xf7s\xdc\x18\x1d'@\xa4\t\xd0\x95\x80K\x9e\xd8 \xac\x8a\xb7"
        b'E\xaf\xbf\xbd\x1cc(OCZlT\x96\x8a\xc0\xc5\xec/k\x8e+lrB\xf5\x87\xa8\xb6YQx9e\xe6\x11\x15\xbde\xb5\xeb\xb6d/\xb7\x98\x90\xf5\xb8\xba\xecn\xd5_\xaf\xc8\xf8\x1cs\x99\x7f\xf8\xc8\xb3\xe7'
        b"w\xcc\xed\xb0\xb7\xfa\x89\x1a)\x1e,k\xb1l'\x9bz\xcd&\xd5A\x1bl:F\x8a\x06\x0b\xe0\xb1n\xdd\xcc)\x8f2$\x90\xe46)BT\x04*4\x86=\xc6\x8e\x07I4\xf9z\xe7\xf1\xe5\xcf\xa6B\xb4\x01\xc5"
        b"\n\xc9\xea\x1f\x87\xbf\xf8&\xcf\x08\xb5\xf05\x13\xbd\x9e\xfb\xc4\xe5'\xf2\x92\x9ap\xa98\x97\xc7,\x9aHO]0\xfd\xf5\x1f\xc7\xd5\xc9\xe8\x8a\xed\xddf$\xe7\xa9V\xc6h\xb0M\xfb\x8dI('~A\xb7\xb3\xc9\x02"
        b'\x14\xb3\xe51\xa7\xabn\xf1\xbbB\xd0\x15/\xf6a\xdcl\x00\x00\t\xc5\x10\xdc\x10\xa8\x1d~\x83\xa0\x8a\x06\xa4\xfd|\xd1\xe3\xacA\xcc\x06\xe1%P\x1c\xea\x99Y\xacv\x1b\x18!LT\xe1\xea\xca\x98\x80|\xed\xaeKv'
        b'\x9c\xe9c\xc8\x8e\x08y\xe2R&7\x01\xa33\x8b9\x8d\x03\x8c\x18\xfff\xbb}\x0b\xff\xe0\xda,<\xf7\xdb~a\xa5\xb8\xe8\x14)\xc0\t1\x0eg\x92)\xc8\xc9\x0e^\xca\x12\x16\xed4\x93\xd1\xb1\x90\x02k\xedh\x0e'
        b'\xa9Y\xf0\x00w\xf5t\xf5\x175T8\xfb\xe8X\x12t\xc7\x8e<\x9b\xa2n\x94i\xa5\x0f\xf4=\x87]\x05\x1d\n\x18O4\xb0\x0c&\x17WjY\xdc\x0efn\xa1Cg\x05\xdf(6\x1c\x815K\xdax1\x05\xe5'
        b'\x01{\xca\xe0\xd7\xc0\xa3\xdf\xbdN\x9d\xc1!6\x13Q\xd4\xb7\x1eyb\x98\xb8\x98\xec\xa7\xa8\x94a\xab\x131N|\x80\xa4Ln>F\x10AB\xfa\xd0\xb3\x9e\x9dEi79\xd0\xce\xee\xfc\xbam>G\xcfc\x14\xe1'
        b'\xa5\xcck\xa0B\x13Q\xa5\xbf\xfaIv\xa6bc\xee\xc3\xf1\x89\xd7\r\xa2\xca\xd2E\xc2-\x9b\xfes\xff\xb9B@\xa6\xcb\xf7\x95\x02\x0f\x01\x94\xba\x12\x8cD\x1b\n\xbd\t0\xfd\xf1\xa2\xae\xf0\xc7\x1a\x17\x86\x85\x1a\xd5\xbd'
        b'\x997\xfb\xa41\xa4\x01\x93w\xbeY\xa7\xf1!K\xd5\xd1YX\xd9eq\tr\xb1\x05I\xac\x90\x9d\xf7\xadp\xf9\x8bC\xb7\x03\x1ef\xde\xba\x00\xd0\x01\xa8U\xe6(\xfc\xa2\x191\x82\xab\xa6Ee#\xd9\tkc5'
        b'?\x1b\xfd\xa2\x03\xe4>\xfe\xd0\xc9HO[\xe1\xe3\xd8\xc1\x1f"\x0e`\x81\x07\xd8\xbeEj\'\xaa\x96\x8c\xba\xfb\xfa\x06t=`\xbc\tL\xf1&\x05T\xde\xecF\xbd\xb9%\xdb-,c\xcb\x1e\xac\xbb\xb8\xc9\xcb\xdad'
        b'\xe3l\x15\xae\xfb\xef\rZ\xc1\x87\xe4\xcb\x1c\x10\xf0\xb8\x84\xdf_\x1d\\\x90\x80\xe7\x7fr*\x9br(\xf3\xb1Z\xff\xe9\x109\x8bb,\xadU}\xc5\x8e\x95\xedg1\x1eW@\xd5\xa5C"{\x01ef\xf7\xb8Y\x9a'
        b"\x8f\xcc\x0e\x8e\xadi\xf8XB\x9e\x10\x93\xec\xa8G\x16\x18\xd1o\xcb5\xc7\x16\x8b\xba?\xfc\x9b\x1b\x15\x1f\xf3\xc7IKd\xaf\xccf\r\xb2\x1d/.\x02.D<\xad\x1d\xa4m\xa3\xcd'\xcbj\xce\x05\xbe;:-;"
        b'\x9b\x98D\xd6$VaR\xd8\x18\xdf\xa2\x15\xdd\xe3\x0e\xe6\xfd\xee~\xfd\x81\x03!\r<.}Q\x1f\x15\xd0V\x8d=\x1f)\xe8[B\xa0\x1df\xc5I\xff+\xf6\x9b\xbb?\xcb\x97\xe9\x92\x9aFj=\xdb=2\xda\xa3'
        b'\x97D\xe6\x1e_|\xff+\xc1\xbeU\x82\xb8\x844^\xf1\xcc\x14\x8e1IMk\x1b\x0fp.d~\xb3\xa1\xc6\xe99+\x063!\x9c\xe1\x8a\xb0\xd6Fp\x11d\xa4\x9c\xc7\xce\x0f\x06\xdf(\xe7\xc84M\xcd\xb2\x7f\x1f'
        b'B<\xe9/\x8am\xba_\xef-}+x\xca\x9cQ\x14\xec\xa8\xf1\xea\x9f/:\xc0\xfe\xc6\x1b\xc6M\xb6\xfa:h\x06\xf1X`\x89\xb0o\x0ct\xe8\xbc\x86\xc1 \x17\xd1\xa8\xa3m\xd6\xce\x18\xa3O\xa7QM\xf8\x87\xd2'
        b'\xcc\xd1\xc3R\xe5\xe7\x80\x0ey\x15\x898J0\x03\x00?y\xd1\xdcd\x10\x99\xc0\xfe\x8f\xecY\x97)Hh74\x03\x0c\xba\x1f\xc1[\\?\xcb0\xed\x90\xd0\x950\x1e\xea\x82\xdf\xa8a\x01\xf0\xf4f\x88\x86\xc7\x82\x8c'
        b'\te\xdb\xa4\x08Q\xb0V3F\xb1\x93\xc9!y?\xc8\xcc\xc90\x9d\x8c`\x85Q[\xdf\xcf\xe5\x10\x89`?\xf5B$\x93\xecY\x0b\x05\xb1\xaaN\x13%\xc4\xcf>\xf9\xf2\x9bd\xa0?\x95?\x88\x06\xf0\x14\xf5\n\x9c'
        b'\xc1\x18\xb8\x9aG?!\xa2\xd0\xdft\xa0?\xee\xe2\x15\x9d\xd6)_\x91\x91\xb8\x01\xfe\x999f\x1d \xde~c|\x9d\x8f\x1a6\xe2\x9a\xc9@\xfd\xa2\xda\xb4\x12\xc7\xeb\xe7\x05\xe7\xd1\xef>\x9f\xe7\xc4\x8fZ9T\xd9\x1c'
        b'\xa9\xd7\xc4"\xb6N!\\\x8cm\xd7\x1d\n\xd7\xc8\x87\x0c\xe1\x05~$6\xa4\x05Ay\\\xe5\x01\xe6p?c\xa6\x90\xab\x8bz\xb2J\x14\xa0\xf1\xc8\xd9\x93\xe6:\xb2m\x12\xdc\x1b\x82G\xcd\xfb5\xd5\x14\xd2,R"'
        b'\xca\x9e\x91\xd8\x92\xd9\xc0\x8e\x91 P\xc7\xd1\x11\xd5\xa8\x9fI\xe9\x16\x9c\xf6\xf8\xe5\xc72\x15\xdf\x18\x06p\x86\xe1\xed\xc1$\xe9\x9d\xb0\x14V%\x0e\xe8\xd4G\xb5\x95(3\xea\xfe\x8a\x98\x8c\xdey\x9aq\xcbz\x07^@'
        b'\x02\xe3\r\xb9|o\x98Q\xda\xdc\xef\xbfY\xe5\x84\x9e\xae4\x1eD\xa7\x0e30`3\x81C\xaf\xb7\x1b\xf6\x1a\xfc4m\xe7\xd6(.1+\xeb{rz\xb9\xf9l\t\x1b]GK\xd5\x00\x0e\x0c7\\(\x8e\x18\x11'
        b':E\x87\x83\x1euTg\xd8%~\xf0\xf1J\xf2\xde\x86\x10\x13\xf1:\xab>\xb8\xd8oV\xc8\xa9\xe9xQ\xe9,P3\x8d\xcc\xf8\xcfs\x9a`\\\xc4\x12uZ4\xaa\x15"T\x13\xe3\x03\x05i{u&g\xa6\x98'
        b"\x01\xf5\x93\xdeN'\xa6S\xc8b\x9a\x13\xa1aR\xb8\x88\x19[\xe8A\xe2\x1cN\xc3\xc8\xb2\x9c8\xb1\x8b\xac:\xfc\xe1\xe7\xc0\x93GI\xaf\xcb\xc3\xc0\xf3\xd1F\xd7\x81\x91\xdf\xd7}\x88-h\xf3q\xdfIu\xab\xae\x14"
        b'\xfdKQ\x87Xe%}\xf3\\\x06\xe5\xdd\xf9\xd5\xf4\xd9\x8d\xbf%E\xf3U5\xed\xf2m\xaf\xae\x93\x80uJs\x8c@\x18=\x0c[\xee\xf0\xc4\x11\x16u\xe7\xd2_\xa2s\xa2_\x1c\x16n=k9\xb66\xf6\xe3+'
        b'\x17,\x01\x8c\x11\x19\xe9QQ"\xaa\xf2\x84\x88>Ky[\xbf\x86\xf8\xf6[0%\xc2\x99b`\xa32\x05\xfdi\xcbt\xfc\xf2\xf5\xa2\xb0\xfc\xa0\x97\x1a7\xf3\x1b\xb5\x1b\xea\xd7\xaeTI,\xc6t\x18FB\xd5\xf7\xeb'
        b'\xe5\xe2\x99\xfb\xd5\xb7ud\x08N$\xc3\xbd?L\xd3\x9b\xa52\xe0\xc6\x05\xe3\n\xa7\\\x03>\xa3\xe5}\xc0&rEW)\x11\x87\x96\xccR\xeb$\xeaB\x95\r\x88.~\xa9\x13\xad\x08\x8e\xbe6\x96C\xa1\x8b\xba\x85'
        b"\xfb\x17\x8a\xc2\xc6\xa1f\x8a\xab?2\xe8\xd6\x9eE2\x06\xd5OF\xd4'>@\xc4X\xf3\x80\xd1\xfa\x17\x1e\xb9\xd1z\xefN\x97RU\xa1\xfe\xb6\x17_\xb9D\xb4\xff\xfa\xc2\xc2\xad\x1a\xad(\x8edJ\xf2}\x9f\x1e\xc8"
        b'e\xd9\xf5c\xe1\x860\x1c!d\xa05J\x97\xf1}\xaa\x88\x19\x8a\x16\x1dO\xe3\x8a\x86\xe9RcVM\xa72\x8d\xa0\xe2\n0\xfa\x8b\xd1\xd6\xe0Z\xa5\xf7uo%\x99\x1b\xf1\xb6"\xa6\x00\xc9\xf1\xa6\xb6\xd7\x0eIU'
        b'$i\xedK\xda|\x86\x12\xcc\xb9\xd2%\xd7\x1d\x05A\xf8,\x8aY\xeb\xe0\xe9r\x02Vd0Ro)C\x86d\x8f\x0eR\xdc\xf7\xfb\x9aTk\xb0\xef\xe1\xf3p\x9b\xdc\xb2\x06\x9f7\xf3F\xe8\x89\xe3\xf3h\x03>L'
        b'|\x0f\x8d\x12\xb0\x94\x93c\xb4\xc9G\x92\x98g\xc1a\x9a\xe7\xd8\xbb9n{\x8d\xca\x06\x91\t\xf1\x80q\x86\x9d\x7f\xa7D!Z\xd6(\x9f30\x99\xa877Q\xd95\xa6\xf0\xf3\xd5X_IU\xea \xab\xe2>\xda'
        b'\x0f\xd1\xc1^\x07\x1cO\xe8\xe0\xd2"\xfa\x8d\xe7\xd9\x84z\xc3\x82C\x1e\xfb\x94i;r\xfd\xc7u\x8c\xff|\'\x8c\x11\xd1?.\x86\xa7v\xf9\xcc\xc9\xc5\xa1\xc0\x9b\xe3L\x12\xdcZn\xc7|\xf0\xdec\xcf\xbb\xc6uN'
        b'\xbc\xe5\xc2&q>\xa6y\xdf`*\x93\xef\xd0"\x9b\xae\xcb\x80[\xec8=\\\xedE.\x03\xa2\xc6\xbc\x80KjXN\xdb\x80\xb7\x7f\x83@\xa4\xef\x04S\x10=\xf6\xb8\x9f\xcc[\xc6\xad\xd5\xfe\xbf\x19\xe0\x03&v\xfe'
        b'\xe5>\xc5g\xc9C\xd3jm\x1e\x02\xb7\x9b\xf5{\x8fc\x1c\x17\x90\xd2\xe5\xee6[\x8f\xfdl|\x9a\x8d\xe3{.\x91\x88\xe2nd\xc6\xa7f\xd5\x10\xc8!R\x01\x92\x04L\xaa^G\xef\xad\xb2#\x03\xcc!}\xd9f'
        b'w\x97\xae\x04;\tO\xa0\xed\x00\xd7\x16,\x92\x0e\x95)\x9e\xfc\xd6\x84\xa6\x10\xf0\xf2\xa1\x11\xce\xc7\x99\xb9\x92_\x19\xee\xf5\xb6 \xb3E\x0e\xdb\x14\xdfs\x81ZF\x0fVG\x99\xde\x8b\xef\x82\xd9\x96\x99\xe3&\xf2\x0b.'
        b'\xc9\x12\xeb\xdcy\x9dj\x95\xc7}/\xc4\xd6\xc6nag\xa9D\x10\xfc(N\xa9\xa0C3;\xde\xe6{:sh\x8b\x9e\xc9\xfe\xd4\x1e\xb8\x81\xb0\xde\x92\xab\x02\r0\\.%\x97t-@sn\x04;\x91\x96\xc2C'
        b"\xff\x85\xf7\xbfX\xef\xf7\x9e7\x81\x01\x7f8-\x948p\x04e\xb0\xd4\x07\xcd\x94\xdf=\xa0\xc7\xecA\x91\x90@N\xc9\x86\x8eL\xcb/\x97t\xb0'\xf5zO\xf7A#j\x00\xfb@\x1f%=X\x11\xc7\xdf7(\x01"
        b'\xa4"\x0f\xdd\xd0\xe3N\xc5\xf2*\x9e\xc4\xaa\xf2\xc0&\xfc\xcd\xab\xfa\xdaaU\xads\xe1$c\xe2\xe6n\xeft\x97kY\xea\xcd\xae\t\x0f\x1b@\xfd\xefA\x99\xb5\\\xffZ{n\x877\x11\xb4M\x07\x0c\x18\x03\xa8\xd1'
        b'\xd2\xa8h\xa9\xbaJ\xb7\x0f\xd3\x8b\xbe\xeb_\ncr\xf7\xcey\xa3\xe0\xa8\x91\x94_!l\x12g]Q$\xe3\xb3\xb7X]\xa5\xd4\xb1\x07\x0c~3\x7f{\xf2?\x81\xee\xcb\x06Jm\xd0\xd5Y\x87\x9a8.;\x17<'
        b'\xa2\xe1\x1c\x86C\xc5_QY\xb3\xb2\xfa\x8a\x92\xfb)\x05\x07\x0b\xf0!\xbfp\x99\xda\x85\x92\x88\xcd.K+1\xd1-\x80?iQt:\xb0\xaa\xf8\x84\t\xbd\\\xb4\xa9\xd9P\x1a-\xd1\xfd\x04,q]gR\x1b\x90'
        b'\xa0C\x05\x83~\xa0PF\xfb\x0fR<e0q\x0b"@\xcdz\xbb\x18.\x92\xee\x84\xc5\x87\xdbL\xf8&\x10r"D\x836-\xed\'U\x96\x1e/\x88\xdeW\xfdGk/\xbev\xa1\x00\xec\xbaY\xe6\xb4\xdc\xf1\xd4'
        b"\x8c\x82\x07\x9e\x175\xf8\tD\xa12HBP\x04\x94\x1fg\x87\xb1\x00\xc18@\xcd2\xc2'\xa9\t\xa2\x1e\xd4:\x9a\x00D\x90\xf7\xe0\xdb\x17\x8e\xf1F\xc5\xe72a\x15U,\x1d_\xcf\xff*\xa2p\xd3V\xcfQ\x99"
        b"\xf3\xc0\xd5'\xea&Q\xf8\x8cc\x81\x0b,p\xba\xcb\x8d\x05\xb3\xe1d\xce\xb9/\xaa+(\x1b\xa3\xde\x05MI\xdfng\xd1R\x85 l\xf7\x01\x18\xce\xa9\rq}\xa5\xb3j\xa2\xca\xd8cl\xb3\x1f\xff\xe4\x03\xd2("
        b'\x18?\x97\xf6\xa6v\x1b\x98f\xf45\xd9\x12P\xef\xb0\x15@\xd61\xf0\xeb\xc9\xb6\x12M2^\xb8\xd81\xffv\xeeW\xd1\x9aG\x12\x1e\xc4J\x13.\\\xcdu\xd1\xa1o\x87\xeex(+\x9d"\x83\x9f\xf1\xb7\x94D>'
        b"O\x8c\x0b\x8b\xaf~>r\xda\x1c\xb0\xf5\x91\xd6e\xfaf\xac\xaeL\xccD\xbe\xad\x8c\xc7af\xad\xc9:\x04\xaaj\x85B\x8d\x9e\x02\x89\x9e\xe6\x14\xf1\x8f\x90t\x07\xea'\xf1\x0b\x83h_\xa4\xfa\xfa\x19\x83mi\x1dw"
        b'\x1f\xed\x9f\xf0\x18\xee<\xc3\x19"\xd9\xa0\xd2\xd2\x10\x85\x9f\xd7\xbd\xa0\xad6\xa2\xe0K\xd8N3\xef,\xb1\xeb\xed\xb0\x1f\x140\xaa\xdcT\x9c\xe6\xd1 \xf7yF1`\xdfC\x95\x03.\x9a%\xcd\xdcI\xff\x05|K"'
        b"U`\x1c\xe1\x1bzP!a\xab\xfa\xe24\n!\x9b\x1a\x90\xa9\xcc\x02\xee=)5\x08\x08\xd0\x8e\x8b\xe9\xbc\x9a\xd14z\xb0\xf7\xc5\xe3\xf1\x8b\xc7\xabZ\xcb@\x1b\x02\t\xc1\x132_u\x95'\x90\xe9\xe6\x98\x8f{\xd4"
        b'h\x02\xe2*h\xa6A\x1etn\xe3K\xecc\x0c\xd7\xdds<\xc0\xeb\x88\xa42\xe9*\xea\xc12\xe2$\xe8\xe8i\xb5\x14\xe8\xbf\xb3\xf1F?\xf8\xd2~\x03\xf9\xd0\xaf\xf6\x08<\xd3\\\x02\t(1\xe5\xcc\x152k\xd3'
        b'W\x06BMEK\x18\xc15\x0c\xab\xbf#\x9eC\x17\xe1\x15\xd9\xcf*n0\xe4\xcb\xb0\xf5!\xd3\x98\x91\x0f\xcb\x8b\xf4*\xfd1D\x80\x99z.\xbbi:U<N\x1f\xc1\x05p\xf8\x8bT\x1f\x17%\xa7\x1f2v-'
        b'7*\xbd~\xf2\xedF|\xc6I\x8fi\xfb\x15\x85\xec\xeb\x00s\xa3\\\xa9\xefr\x02r\xe4 \x83!\xa0\xa7\x08\xa5K\xef\xa15\x11M\x86(\xf7\xbd\xe2F\xc4\xed\x9c/F\xedW\xe1\xe0\xca\x1cMj\x02G\x1c\xa7t'
        b'\xab\xcf<\x85*\xc2&\x88?z\x9e\x14Bm\xdc\xa8A\xd2\x1b)\xe7#\x8a$#\xb0\x0f\x14P\x9c\x95\xe1\xce"b\x10\x83\x00\x9d\'/\xffUt\x8b49\x88w+\x19H\xdc}O\xdc\xf1\x81\xe0\xbf\xf7\xbcxQ'
        b';\x84\x06\xce\xddy\xe3\x1c{\x82\x8b~\x9c\xa1\xe7\xd6\xde\x12\xee\xd1\x07\xd9\xa2F[)G9<\x9a\xe5\n\n\xea\x8f\xf8\xb4\xabJ\x9b%\x17\x17\xfbI\x985\x87\x93\xa6\xca;\x98\xa8;\\\xa5\xfe\xe1\xe2\xafn\xb2\xbd'
        b'\xd1\xcd\xcc|4\x0c\txNw`!\xe7\xce\xb5\x11:\x97\x086e[\xe7\x05a\xa2\xa6<\xec\xabrG\xffR\xd7\x9b\xee\x9ao\x99\xca\xb4\xd5n\xeb_\xa2\xa1qK\x8e\x90\xad\x8f\xb0bJ\xa0\xf5\t\xfd2\xafX'
        b'\r[\xe6pb\xbfl\x9c\x08R\xc4^\xd0\xfc\x91\t\xc3\xdc\x99\xb7\xa4\x90\xcc\x17W\xbc\x8a\x7f\xb9\xac\xfb`A\xeaJ\x98\x19\xce9J\xab.\xf0\xa7\xa0&\\\x93M6\x87\x07\x16\xc5\x8a?t%\x04O\xb7/\x12c'
        b'Gl\xe8z\x0b\x0fF\x9d\x07T\xe8b\xac\x9a\xd5 &s\xb5]Vs`\tM\x9e\x94p+&#+\xbb\xe4\x97\x04\xc2\x1ee\xed\xdf\x94\xfc\xac\xa8\xe0Z\xc7\xd3\xbd\x0e\x7f28*\xac\x00\xc3\x15s\xc3\xe5\x95\x96'
        b'\xf1l\xe2\x14\x8d\xc0\x95\xa6M\xfc\xa3\x018\x1b\x91\xda/\xba\xba"\xd2l\xa0\x0e\xd9"\xe6\xd9Y\xea\xb2\xb1\xecUX\x97\x86\x11\x8d\x84\x83\xc0\xa9\xeb\x07\xdav\x15\xe7\xf8#\x11|\x8e3_\xd5\xff\xeb\xdc\x98ez2'
        b'\xadBTY\x0f\xb60:Y\xee{z\xecR\xe8\xad\x90.\xaa)\x98B!\xe7e\x11\x1a@S+I\x884\xea{\xd7n\x87\xd6\xf3B1\xfe\xe1L\xec\xb9@\x15\x99@/\xad\x18\xc7w\xc8\xec\x97\xab\xa6\x8d\xcdl'
        b'l\xf1\xb7nWn\xef\x1b\xf21"htB\x152\x81<\xe4\x17\x86\x03\xa4\x84I\x17\x94!\xff\x85Q\xe5\x8d\xa1\xa1\xd7\xff\xf2@\x16)\x82"\xb9\xfc\x92&=\x0bf\x0e\xe5\xb5a\x919\xd0\xb3~\xa2I\xaf\x98\xf8'
        b'2\xa78k\xf90\r\xc7O\xdc=\xcc\xc3\x12\xb2c0\xf8O\x1f\x0c\xb7d%\xa4<\xb62^\xba0\xedQEj\xb8<9\xcb\xb7\xd1\x86+%\xd9\x93\xf5=\x18\x91G=\x02\xbaLW\xed\xcb\xccC\x85\xda\xf4q'
        b'\xe7\x1bVQ{\xcc\x15\x14\x96\xe3d\x8dcKx`I\xa2\xfe#\x04eB\xe1\x95\x95\xa6\xdf|\x86\x91\xc1\xb7C\x878\xbc"\xbb#\xca"J\x9e\xa2\xe1a\xdb\xa5h\xabbg\x87\xb6I\xc0Lvp\x94\xc0\x1dN'
        b'uAO<n\x00\x0c\xc4\x96\x1f\xa9\xe9\x93YEs#\xd7LS\x7f\x80\xd4X\x97\xb0\n\xb1\x1b\xa2\x1c\xf4\xe4\xcc\xbe\xb6{\xc3*\x1eI\x97\x13r\xe1h\x1b\xf9\xa3\xf7\xba\x07\x81\x0b^L\x11\xea\xc7[\x86c/{'
        b'\'\xfd\x85\xd7T\xd8\xa1"\x00\xfb\xa7\x03\xa6\xef\xe3}\x02\xa3O\xa7t\x96ow\x86\x1cK=$\xe4\xe6x\xfa9tOg\xc9:\x16\xfe\xbeC\xe8\xd0u\xcb.\xe9\x18\xb9\x7f\x0b\xff|x\x05@\x1b]\x88\xec\xd5\xdf'
        b'?\xf9\x88zh\xec(\xc0D_\x19\x8dZ\xd5\x83\xceH\xe2+\xcf\xc1\x9aq\xd4\x81\x10\xd4\xf2\x80U\xd1GcB\x82\xc9\x9b\xd0N\xca3\x1a\x15\xd8>\xfe\x10m\x9f`\xd3q\xff\xb6X\x05:\xa3\x97\x8b\xa5\xd4e\xab'
        b'*\xf9\xf4(U\xe6\xa3\xd6R\x14\x9a\x07\xe6\x80\xd4\xaf#\xa0\x04\xdf\xd2\x9b\xebu\xce\xfd\x7fS\xe0\x83<\\\xb9\xfb\x84h\x14\xa9I8&\xfcP\x9di\x7f\x94+\x17:\x0b\x03\xabK\xe3]4\xf5ag\xf1Z  '
        b'\xbb\xb0^(\xa4-L[\xaa\xc4\x87\xceR\xe1\xbc?Q\x12\x0c\xf2bh\xf8\xa7\xf4\n3\x0c\xfd\x83\x03Yn=\xed83\xce\xe1\xd1\xf13^\x85\xa6\x06\x0b\xd9\xd8\xd0\x14l(\\\xb9f~{\xcb\xad\x89\x94"v'
        b',_1)!6\x03u\xc1\xdck\x01\xc9\x8ag\x9d\xcci\xa4n\xa8y#\x02\xa8\xcc\xc8\xcc\xbc\x02;\x93I\xec~;0`\xff:C\n\xf2\x00\xbdF\xd00O\xe7\x94\xf2;\x8e\xc4\x05Q\xb7.\xf2*e\xe5\xe0'
        b'\xab=\xe6\x8e|\xd3~\xe8\xc2Q/\xb9\x8d\x8aO\xc9\xc1=44\xb5\xc9=\x14\xc8\xc7^F\xb9\xf9v9"\x15\x90\xf7\x06/\x90\xd2a4\x1fH<\x1a2\xbe\xbb-\x1a\xf8\xbb\xb97\xab\xa9\xbcm\x9ex\xa6\xf7$'
        b'\xa9\xd5\xf3R\xe8\xfd9\xb6\x1e\x9e\x12\xb8\xa7O\xd0>_\xb6*\xb3b\x03\x9a\xb1\xcd\xe4\xdch\xc4\xb2\x18"\xeaq\x81\x07\xc6:\x01\xde\xd0Yt\xb8\x14\xeb+9\xd5!\xd2\x12i\x90O\xa4\xae\xf3\x1ab(\x01\xca\xf3'
        b'\xaa\xa0\xbcO\\=\xf9\xe5\xfa\xfez\xa6\xf7\x1e\x98/\x9e\x98\xde0\xaf\x0b\x05\x93[\xd6\xbeo\x1c\xa1\x06\x8a\x85Y\x15\xe2\xbd9\xc4\xd5\xcb\xcf_?$\xa9sX\n\x96A]\xa0|\xb4\xa4\x97w@\xdcz>\xaa\xf5'
        b'hqB\x18\x7f\x1c\xae\x17J\x87"\xc1\'.hHRR\xfaI+N\xc3\xe5\xa3\xfd^\r\x95B\x88\x10Y`\xc1\x91\xadQ\x95#_\x8e\n\x01\x80f\xaeu\xb2\x14\xba\xa8\xdd3\xaa\x16\x0c0\xd7\xf8\xeel\xdb\x9c'
        b"\x882\xc9\xf1\xca\xfe\x0c\x1cB\x05\x03\x97\t\xf7'Q\xa3\xdbI\xaf\x88\x181(\xfe\x08\xcfq8eR\x1e\x9f;m\x9e\x94/\x04\xf5x\x02#\xa7\xf6\xc80\xca\x18\xe3[T\xb2\xa1\x1f\xcbg %\xffOw\x8e\xef"
        b'i\x11e\x02=b\x18\x8e\xcf\xd8HQ\xe1\xefv\xd8Q\x17\x1f\x14\x0c\x08?\xdd4\xd4$f4\xf3\x0c\x00X\xaa\xb0e\x18%Q;\xabT\xd7^\x00a\x0f\x0cU\xa3\xf2c\xa3*"8\xc5kR\x85\xe7K#t'
        b'X\xb8\xff\xc2\xb3.\x89gg\xe5A||\x83\xd3`\x8c\x1d\xa3PM\x19,;@v\xad\x8f\xa8<\xcd\xc4u\xb6I\xc5\xb4\x88\x97\x03\xb1\xa5u\xa8<\xaf\x17cp\x14\xaeSV:\xf5\x12\x80t\x9fBp\xe1\x0e\x98'
        b'Ph\xca\xb1Yw\x88j\xa9\x05\xf6\x99Q\xc1\x13qY[#Y,\xefpI\xf5\x16Q\xeb\x95\x83\xb7\x91r\xcc\xb4\x18\xf4i\xe4\x18\x11\x83\xd1\xfd\x8d\x011\x07\xdd\xbc\x91\x18\x8b\xe7\xc0\xc1\xf0\xa7\xcc\xc5\xa8\xcf\x9bs'
        b"\xac\xfa\x00\xf6\xdc\xb6;O\x80+\xb0\x11\x87Jay\xe5\xb9d\xe1=#\xe0\xa5\x19\x7f(\xd1\xd1\xee\x8fl}\xa2\xd3\xdc3\x9b\xb2\x02\xd8)\x96[\xd0\x83\x0c\xf2[\xfa\xd3\x07\x08\xcd\x14\xd6\x95\x0f'@\x1f!\x92j"
        b'\x81#\xd4x\xdb\x98\x89d\xa18z@N\x01\xa3\x1a\xcb\xad\xea\xc7\xa7I\x02\x16\xac\xf1\x97\xc90\xe5h\xd7\xc5\xaf^\x18H\x17\xd6L4\xc9\xa6\xe2\xb3\x99\xbaD\n\xa2\xa2\xb98U \x0c\xf4\xa7<lT\x90\x9c4'
        b'\xf7O\x0f\x84Ka\xc3G]\xf5\xd5C[\xeeZ%\x07\xb8\x16\xdc\xdd\xd9JV\xe7-\xe5F\xf6\x99\xf7\xe8\xc3\n\x07\xc0~\x8b\xe1\x98=\xa1\xb7\xe6Y\x06k\xd1\xc5,\xe7r\x13=\xfeG]Dl\x9f]\tY\x81'
        b"\x05\xde\xa99!\x8e\xc5|Dy\x14Q\xfa/\xe7.\x83\x0b\xb5*?\xb0\x94\x99\xe1\x19<\xef\xaaK5\xe4\xca\xf1\x13\x1a\xebV\x8c\xee\x93\xb97c\xdb'\x87~\x88*w@< \x0c\xc4\x89\x18\x08\xf7V\t\xce\xa1"
        b'Tb\xcd\x01\xd0\xbe/\xcf\xe3#H\x9aa\xbe;\xeaO\xab9\xea\xf9\xc2&\xabg\xad\x13K\xcb\x07\xf0D_CX\xe4\x8b\x8a?\xbcI\x1fR\xccv\xdb<\x84V Y\xe4\xef\x8e\xc3\xc5\x85F6\xcc\x9b^Y.'
        b'G\x94\xa7\x81\x0b\xdf_4\x1f\x08\x1d-J\x95\x11\xe0\x92\x81$\x93\xff\xc5\x11[,\xea\x05P\x95vU\x8e\xee\xb7\x0f\x9e\xeb\xca\xff\xf9\x87\xf4\x9c\xa3\xe8\xb6\x17O\x84\x95\xf1<\x16\xe2\x01\xe6\xe6\xae/\xf8\xd2`\xd5u'
        b'\xe0\xa1l\x8a\ts\\d\xe3\x7f6\xa2b\xad\xe9rx\rN\x9f\xac\xf8\x89\xca\xda\x80\xb3FUd\xe0IlN\\\x07D;\xba,,\x13D\x97B\xee\xdb#\x97<\x1b\xa8\xf3\xeb\x1b\x02"\xbc>T20\x83\xb1'
        b"\x14s\x88\x8d\x96\xadh>\xc8\xeb\xd0\xd7p\x82\xbd\x81'\xbew\x07\x17\xf2\xf7\x01\x93KX\xd8\xc6\xce\xf6\xc4\xa7^\x0b\xe9\x95(\xe6\x07\xd4'\x8dr\xe7\x90\x8d|HFoc\xa4\xc51dXxX\xf2;\xdb'd"
        b"\x88\xa8\xf7\xddj9\xf6\x9c\xa4<!}\xca\xe0r\xb0\xc4w\xa1\x91\x81\xd9\xd0I\xc6\x03Q\x96\\}\x1f\xe0\xbdC\x9e\xcaa\x9e\xab\x8d+\xe3\xee\x81\x8dM:\xe4\x1e\xdc%'\xc1\x83\x8d\xf4R\x0f[1R\nZ\t"
        b'\x15\x8d\xf0OM\x9ff\t\x17\xe1\xdf\t\xfe6#\x9b"\xf6"\xec\xae)\xad\xd2i\xe0e\xf9.\x02"\xa7u{gP@D\x0b\xd3?\x90\xc4\xfd\x88;\xf3\x9f\x87u\x1b\x9b\x1b\xbb\xb8\x1dm\x17\x8d\xe4\xe5\x02W3'
        b'U<\xf4\xf4c2\xfc\xe3\xeaSdPS\xdd\x0e\xa7R\xcaG?G^\x11>\x99\x8ex\xc3\x88\x87\x1d\x1al1\xd9}\xb5Z\xbc\x82o|\xdaT\x147\xc5\xeeC\xe5\xccE\x15q\xb6\x96x\xf8\xb7FU\xd3\xdfI'
        b'H*\x9a\xa8\xce\x06\xeeh\x12D\x0f\xf9\x92C[\xae\xab9\xd5\xcb\x14\x1b\xd7/\xd0\xd7\x93\x99\x89X\xee\xcclqj\xd7e\x9a\xe9c3"\'^Q\x95\xa3#)J\xe8\x06ql\xf6\x98\xa3\xa9Iw\xe5"v\xd8'
        b'@V\xdbL\xe2\xc6*\xdb\xb6\xe8KeIY|\x0b\x96LN\x8d\xf8\x06\xf32P\xf4\xd42\xc2\xca\x978g\\\xf1jI2\xdf1\x89m\x06\xf7+?\x16\xf1l\x0b\x1c\xf0\xd1P\xfe\xb4\n\x9e4JX\x1a\xc3\xa2'
        b']\xa1\xb0\xd4\xb0o\x97}-k\x8a0\xd4\xce\x04([\x88\x7f7\x00ox3"\x97\xea\x8f\xb2\x1b"a,n\xd1\x13\x14\xf8\xb7|I\xa2\xf1EZH\xc61;\xd4\xe8\xd2h\xca~\xd8\x148tW\xfd\x9d\x9c\xa1'
        b'\xb8\x91\x8a\xfc\xfa\xdf\x814\xae\x8c\xbe\xc9\xb4\xde\r1@\x96}\xd2\xbb]\x074\x9b\xf2\x0b\xa3\xa3Lf\x06\x9cJ\x99\xc8\xea\xfeg\xe0\x9bi\xbb{\xce\xa9\x9eG\xe2"zl\x94\xb1|k4i\x08\x00\x190\x16q'
        b'N\xbcb\x92\t\xd2\x86\xb4n\xe2(2)P\xbc\xae\xe8\xc6\x15\xa6\x17e\xa2b\xc4\xc6/\xdaf\xa6\xc0\x1b\x96\x18\xfd\xa60\x94v%\xbd\xec\xd6\x1c\x87\xcc\x97\xd2\xb1\x03\xba\xef\x8d\xe1.\xe6\xc6o\x90#\x9d)W\x1a'
        b"\xd0\xfc\xd6\xd1V\x02\x8f+x\x02K\xf6\xe0\x92\xa9\x90\xe7\x10f\x8bFw\xe0P\x0b\xbbI&\x86tv\xd9\xbc\x8e\xd4\xeeXL\x05\xef\xde.\xdc\xbc\xc7'z\xcf\x01\xb6\x16\xb0\xb9Y\xae|M\xe9X\xf1s\xe6\xf5\xf7"
        b'\xb9\x96\x8eL\xb7Z\xdd(\xa6\xe7Y\x14\xfe\xc7\xf5\xaf\xda\x91\xd8\x8e\xc2\xe8&\xaa\xcf\x0b\xd7\x07@\x8dw \xff\x17m\xf9\xdd\xd3t^\xdc\xf0\t\xaf\xbb\xb9\xc1\x15\xc14\xc8\xb3\xaa\x84(\x03\x00\x02\n\xab\x08\xd5\x94\x97'
        b'#\xae\x8b\x9e\xf2_$\xde]\x06W\xfaW\xa5\x80\x07\x95\x0c\xde\xaap\xc0\xd2\x05=7c\x9foy\xcc0;\xcc*Ctq\xafV\xc3-\xa1\x1ah.P\x00\x9e\xde\x8b\x1a?b\x83\x03\xc1-VU\x1d@\xda\x9e'
        b'nG\x83\xb8\x95V\xae\xbbp\xa1\x93!\xef$\xa6\xfd\x87\xaeh\x93\x18\xcb>[\xf1\xa2e%XfmgY\x18NSCvM\x97\x18J\xdb\xe03\x99\xa4\x1d\xba\x92\xd9\x12\xd3\x1e\xe6\xc5\x03)}\xfbWQDy'
        b'\xab\x00$X\x1b\xfe\x95\x88(\x90\xc3\xc51\xd7CdC\x1eC\xff\xbc\xe6\xe6\xdd\xbe\xc9\x87\xfe\x00\x11\x9f\x04\xc8\xf4\xd0\xbad\x8d\x95\xf1;L\xda\x19T\xcd\xaa\xef\x86\x8d\xbaD\xfd\x82\x91\\\xa8,Y\xf8\xa7b\x8dF'
        b"\xcb\x89\xb4j\xaa\x93\x93\xd2\x02\x90 \xd1I\xba\x06\x88\x83\x1f\x82r\xea\x97\xaevZ\xd3\xbaj\xd0NB\xd2\x16'cv\xb1\x9d\x1e\xd1\xeb\x81[\xcb\xab\x19\xd6\xb2\x1d\xa3\x1c\xb8aK\xb0\x8f\x16\x04XwO\xddS\xec"
        b'\x8fY\x99Hd\xed\xdc+\xa4\x89\xedG)\x92\xeb\x9a\xbe\xad\xcd\xe7L\xe9a\xce;\xdd\xbc!W\x08\x15;\x94\x94~\x8ai\x00\x9dq\x83\xfd\xfc\x95\x1a\xfc\xa7\t\xdd2f\xff\xd0\xeci\xd4\x95\xc4\xff+\xfa\xfbg\xdb'
        b'\xb0\x99\x9b\x92\xf6\x81e\xb1\x92\x19\xb1\x00\xeat\xf2\x88\xa9\x8d\x16\xe1\xff@9:\x07L\xa7`}\xee\xbd\x98D\xeb\x95Q\x97\x03\xda\xf3\xcd\xdc\xdcE\x8f\xa9\xfb;\xbcE5\x11\x9a\x16dyq\xedk\xc2=M=5'
        b'VC%\xf2\xcb-\x9a\xa5f Z\xd3\xba\x03Z\x85\xb1n\xcc\x92\xb5\x00\xa9\xe5\x1ao1@\xd0\xe6Z\xc3\xc2\xeb\xfa\xca\xfb1n\x83\x16w\xd0q\x91\x0fk\x00\xfd\xe3\x1a?\xad\xb5e\x11\x00\xbd\xf9\xe5B7\t\x0f'
        b'\x85\xe6\xae\x84\xff\x81\x0b\xa5\xd2\x15\x98\xd8\xb4\xee`\xbaZ\xec\xba#\x87\xe5-\xdaz\xec\xeaa)\xafpX\xf1\x87\x1e\rTU\xeb\xad\x01\xafF\xf5\x07\x89\xd3\xfdD\xf10\xa15kV1R\xa5U\xba\xc8\x83\xa1\xee'
        b'\x89\x83a\x156\xfcl\x7f5_\xbb\xe9gj2b\xd8\xc5\xf1\xd5\xe5\xd4\x9b\x0b\tB\x05\x1dr\xa5|\xea\x85\x15\xa9\x87R\xbf\xe3g\xea\x88\xdfC\x8bt&KJ\xd3\x0f\x99\x89\xccu\x11o\xff\x1a\xd5T\x1b\xa8\xe1'
        b'\xed\xa4\xca\x95\xeaO6\xa6(\xc3o\x98\xe1\x02\x86\x0b\n\xfd\x14\xc3\xd1\xb3\x82\xd3f\x88\xd17\xa1\xf1\x18D\\j\x18\x13M\xb6\xef\x8f3\xde\x1f\xf1\xc2\xd1{\xd5\xc9\xa0r\x04\x9c]U\\\xf9\xbc\xfb\x19~\xa4L\x84'
        b'\xf5\x94\xedM\xe2\n\xdf\xdc\xb2T\x86\x01\x00\x03\x81\xb2\xd8NY\x94\xae\xda1f\xb5\xe0\x8d\xf0\xec\xbb\xbb.\xef\x9e\xf68\x93\x84jN\xdb0f\xd1J\x9a|\xf1\x8c\x0b\xc1\xabM\xbe\x92\xa3\x15\x01\x04\x10\x0f[\xc0\xf8'
        b')6\xa8\x99GH\x18\xfc\xf8Iv\x17<\x86m\xd9\xa9e\x1f\xff\xeaBU\xc80\xe5\x93\xd2\xe8Z\xd7:d\xa3\xc9\x16y\x19\x82\xceW\x88\x126\x86\xc5\xa0\xb7\x95\xc4\xdcDo|,\xde\xcavp\xd3y\xf5\xe4\x11'
        b"l5l\xd3)\x84\xb3a*x\xf7\xccJ'\xc6r\x1b\xed\xb6\x8a\x16lZ\xd1\xeb\xe6\xe4&$\xdb\xb6\x0b\xec)-\xb5S\x04\xe0\xf8y\xff\xfd\xe9\x0fpN\x90f\xd8\xb4\xf5\xb2\xd0\xb4\xf6L\xfe\xee\x97D\xd7/\x0e"
        b'\xf2Ww\xf0.\xe9\x83\x97\xbf0\xc8\xef\xacyXVFw\x91\x00\x7fw1\x9d\x10\xbaL$\x0b\xf4\x85U\xb0\x90\xed\xee\x86\xeb,B\x0b\xaa\x8b\x99Qb\x17d\x10\x7f\xed\x0c\x1a\x0fWt\x7f\x18\x11Q\xf6?\xfd\xbe'
        b'\xa7\x8e\xbbd\xbcnNq\xf1\x0f\x9c\xf54oJ\x08\xe9*\xfe\x83\xd6\x82\x04.n\x99\xa6\xb1j\xef.\x1e\x0b\x9d\x8c\xc2Y\xc3\x9bv\xac"e>N\xe0\xfb\xf3n\xcdp\xad\x08\xc3#T\xaa\x1c\xbeA\n\xf3s\xbc'
        b'\x99\x93\x88\xeaS8/U\x05\x00\xa3R\xc7\xc8\x89\xc3\xa6I\xb7\xc9\xd0\xcc\xaa\xe2M\xd4\xd7T\x86\x06\xb0\n\x9a(\xc6\xd1\xe7C\x9e\xe8\xff\x98\x8e\xaa\xb9\xce\x045\xd2&\xa8i%\xdfl\xe5\xa2\n\x7fF\xdd\xb6\xd7\x01'
        b'\xaf\xd93\x87\x00\x8f\x8d/\x0c\x07\xa4\xc3\x13\xabF"F\xff\xf8\xcb\xeb\x9c\x89\x8509\xd7?}\x05\xfa\xa2\x87\xeb\xe8\xd8\x9f\rx\x05F\xf4\x8a\xfd\xd9\x8f\x9ft\xf8k\xb5\xfa[\x05\xc8dls\xb8\xa8!q\xd1\x84'
        b'\x15\xd7\xa7{\x97\xb0\xd8E2\xf1Lt\xa2\xe0+0!\x1c\x1f\xbe\xe90\xa2\xb1\xd8\xf7nR\x9b\xd7\xd5m\xec\xa0\xb8cB8\xf1`\xe4C\xa1\x1d\xb5\xa9}x\xe2\xb4q`n\xa9*\x07\xd8\x9f\xb7\x98\x9c\x94\xaa@'
        b'z\xf0\xd8\x1b\x0c\x9bn\xc0\xb7e\x92\xb2\xaa\x0e\xb3\x8c#\x83\xb2m\xf8^\xf3\x9c;\xf5\xdb&P=\xa7\xa1\xea\x97\x1c26(\x14=\xb6\xb3k\x1bN\xb0\xf9~\x8a&\x84^\r\xdc\xad\xde{\x1a\x9c$o\x9e\xe9+'
        b'\x84\xe1F\x98\x08\xc1\x0cm?\xd9\xb5\xca\xdb{I\xfb\x001\xb2Pl\xee\x9cT\x98h\x11\x18\xe1\xa4,M\x80\x13\x8f.>\xa0\xc7Q\xca\xb1*]\x13M\xb1t.\x95\xbf\xd0\xe8L\xcaL\xd9U\xfd\xa1\x84\xb8o_'
        b'\xeaT\xb1Gg\xe1\xeb\x85\xf2\xe0uj\xf9\x8b?]\xcf\xaew\x866~:\xc2o\x1b\x885X\xf5J\xc6F\x1dT\xee\xdf\xd8\xdd\x00\x1b\xe9v\xb2C\xcf :\xc9qp\x82<\xbaV\x7f)N\xb2\xc6\x01\xfa\x9c\xb3'
        b'A}\xed\xdb\xdc#;\x11\x14K8\x98\xf3{y0\xe4\x91\x7f+\xcd\x88\xe7\x89\x86\xe2$\xc8"\x823g\xdc\x98\x10\xbe\x15\xc8\xc7[\xbe\xd7$\xa4\xab\xc0\xb2\xe9C\xba\x86\x1f\x8dU\x8a&\xe3\x1cn>\x82P\xf0\x89'
        b'\xba\xf1*v\xf0]\x1e\xca/\xb1Wd\xb0\xfc\x05\x10\xbc"\xe1\n\xf1j\x8f\xe4m\xf6&\x08\xd8\xe0-?>#\xc2\xed2\xfe\xe2\xd1\xd76\xe1\x957\xf5\n\x13p\xba\xea\xe7\xda\xc1\xf2\x8d\xc9\xa1DR\x8d\x81\x06\xf3'
        b'O\xb2\xa9\xdb\xe7\xfc\xbe\xc6@Z`\xc6i*\xd0/n\r\x90\xd9S\x96+\x05\x80z\xbd\x13+\xdb\x9bq\xb0\xe4\xea\xf6U\xff\xcb\xb8\xe04p\xb5\x90k\x02P\xe1\xd9\x19\x15:&\xeddG\xed\x82\xb9\x14\xb3\x8em'
        b'?<\x9a\\c6\x9f\xbc\x86R\x17\x9bNd@1\xaeN\x7fu\xbb\xe7\x076\xcfC\xa6T\xc5tmE\xfa\xd8q6xy}m\xe3\x0b\x8b\xa6\x90\xf2\xf1\xecU\x15\x97\xc2\xa5ZG|\xf6\x14\x9d^U\xda\xf8`'
        b'^9\xe2\xc7\x10\x8c\xd5:\x17\xfd<\xd2\\^\x1f\x14\xf8V:-W\t{\x93Vw8\xdf\xee\x97\xda\xb06i\x0f;\x1b\x93\x8e\xe1\xef\x11\x91\x87\xe1\xda\xed\x0b\x14\xaa2\xc7\x08F\xd5p\x1f\xe5X\x8b\xb0\x14\xe2>'
        b'\xd1\xe1L\xba\x95\xd3\xbf\te\x0f\x85_ \xed\x11\xdb\xd6R\xd2\x01\xab\x03\xfb\n}\xc1!\x96\xbfb/\x8b\tC\xc9\x9a\xd7c\xf1C{\x93\x01\xd9"\r\x06D\x9eS*\xf7\x86I\x93j{\x14%\xad\xdd\xba\x19\xaf'
        b')\x08\x90\xf3\x87!0\x9e\xf4\xa4\xe6\xd3\x01\xff\x81ha\xc7\x0biy\x1f6\xc7\xff\x84}4\x85\x8eI\xa6\x18\xcb8\\\x96\x12\xa4F\x04N/L\xf7rh\x90[q9\x98o\xe0\xcd\xee@7\x14bc\r\t\x82'
        b'w\xc4\xcbW\xa74\r\x89&\xf6\xd0k\x06mE\xee\\\xd4\xbdk`\x11\xfb\xbf\xbb\xc2\xa9\xbd#rz\x13A\xf8\xc6=o\xa1\xeev{\x1fWG6k\xb7\x1d\x87\x1df\xd9\\D\xdf(\xd3#\xeb1\xe7|M\xad'
        b'\xc0\xb5\xf7?\x8eWSc\xba\xa5\xc2\x1d\xf1\x98M\x04\x81\xdd\xb1\x1dB\xd8\xecZ\xd9+O\x0c\xca\xd2\xaf/JfL\x96\xc2\x18\x91\xd9F0i\xc3\x13\xb6\x04\xf0)v\xe6\xbc\xaeS\xcd\xa2\x9f\xf3u\xadoL\x00\x97'
        b'\x11 \x03\xd9\x15\xa2\xb6\xcdd\xf2&\xcb]M\x88b\xfe\x07\xf5\xfa\xbd\xea\xf0\xa0`\xd7\xda\x82\x96\x8d\x13M\xb77\x04r\rR[S.\xa7\xabq\x8d\xb5U\xa1\xd2u;\xc3\xcb\xebR\x15=8\xf9-\x16g\xf7\t'
        b"\x1f\x85\xd5\xca\xf6v\x9b\xc3\xa6xw\xe9+\x7fo\xb9\xd1\x08\xc1\x99A>\x03\xc6\xba\x91\xa2.\x80\xcc\xe6\x9eo\xab*VV'f\xcc\xee\x15\xbe\x83i0\x07\xf46\xbc\xc5-\x83\x94\xb0\x99h\xe3\x04s\xa4ySf"
        b')\x9a\xf8\x91\xc2\xfc\xd4^\xe1\xe6\xf4u\x11\xfa\x83\xb4Y\xd34\x13rh\xf2K\xfexE\x84\x1d\x9bQy\xff\xf9\xbf\xf4\xb2\x03\x99T\x0ef8y\xac4;\x11\xa2\xe7^\x11\xd4\xd4S\xff\xf3\xe9\xa4\xaf\xb7\xbf\x99x'
        b'n\x8f\x97\xa3s\x18\x13\xf7\xb0\n\xe7\xf8yb\xdf\xbe.\xf0.\xb8\xdd\x82Z,U\x06\x15\xff\xef\xc8\x0c3\xa8=\xc5u\xab\xc2\xdeG\x12\xaf\xf4\xc5\xae*\x17\x03\x83>\xc4\xf2\xa0Dg6\xf1\xd5k%@\xa1\xdd\xff'
        b'\xec\x02eN\xef_Z\xd3\x86\xbf`n;\x04c\t]\xfa\xcbw\xaej\xec\x07\xee\x13c\x95/\xfa\x88\x85B \x91/\x90\xa3\x02\x9c-\xb8\xa6-\x9a\x9d(\x1c\xf4\xfd\x00t~\xb1-bvW\xf1\x83S\x93\xaf\xad'
        b'\xf8\x1e\x96\xa8l\xcc \x051\x05\x95\xdap\xf0\x9c\x91\x91\x13T\x7fT\x0f#\x1eK\xa7\xac8`\xa6t4\x81\xa1\xfd\x86jF\xf5%\xd9\xfe\xef\x80\xb0|\xaaR \x90\xf1Z<4\x80-MIS\xd7\xf8U<\xcd'
        b"Dk_>\xf2\xec~\x1dZB=\xe1\xa7\xf0!{Re\x86#\xae\xd5p\xa2\xa3\x15\x85G4\xe9u\xec\xe7\x8brr\x83&R\xdfQ\xa5\x17\x0f\xba\x81\xc9\x0en!'\xdd\xd3V6g\x88\x8f\x9aRF\x0f\xed\xce"
        b"q\xc6\xa0=;\xb2\xca\xb4\x8a\xe4\xe8\xceg\xbdL\x94\xefZ\xdfb&'\xee\x06\xb7\xc8\xd8\xf0\xe5&~\xef\xad\x97\xa9\xc7\xd6\xa8\x98:\x8d\xf8\\\x1e\xa1h\xc0\x9bd\x13\x0bB\\h\x91V5\x8b\xaf\xcb\xe1\x0b\x92\x83"
        b'\xf9\x80\x99\xbd\x08\x9f\x9d\xc9\xa2y\xcd\x1c^\xc8s\xb6\x96\xad\xfb\xb9\x97\xef\xf7\xaf}\x8d\xfb\xbd\x93\xc5\xe3\xb2O\x1d[P\x92\xed\x95\x1f\x93\x04b\xe6\xa4\x81Y\x14\x97\xbe\xb3I5\xed\x11\xc0\x86D\x1d\xf9\xbe\x1b\x9e\x1e'
        b'\x1bRnGx\x94\xbb\x1c\xc2`\xed\xabb\xa4]\xbfj\xdb\\y\n)\xaf\r\xc3\xa0\xb2D\xc6\xe9\x86 \xf4\xad\x9d\x0f\xecnbMN\xcb\x97\x87v\xbc\xef\x9dc\x86\xd6f\x8f\x7fQ\xb2L\x95\x8c\xddq\xfe\xbd2'
        b'Z\xdb\x95\xdfz)Y\xb1r3\xc2\x9d\xeb3\xf7\xb3\x17\x8770\xf3\xc1\x9b\x9b\x0e\x9bp\xb9\xbb\xe3\xc7\x08\x95\xc3\xe2\x83\xbb\xad\xde7\xed\x03\xebk\xb1\x15\x95\x1f\x9a)\x84\xb7T4\x11\xed\xe3\x12\x83\xe8\x7f\xc6\xd4\xe7'
        b'\x1f\x9airm\x190\xf42\xda\xe1\rT}y\x95\x87\xbd\x9e\x96\xf6D :\xf6\xdb4\xc2\xd6X\x02\xab3\xf5\x99\xc8\x88\xa2d\xfbZ\x11\x90:\xfd\xe1,\x1b\x88\xed2\xcen\x96yR\x9c\x92TU\x90\x99]\x8a'
        b'\xf9\xc7\xdb\xc8o\x95A\t\x18\xab\x0e\xf02\xfbbq\xf2E\xa8$\xa8\xf5y\xcb\xe8\xe0W\xac\xd1Od\x1cp\x80\xeew\xf0\xfb\xf1\xc1fzB\xa3\xa2\x89jU:}\xab\\\xe3n9\xf5\\7\x13P\xc37\x80\xc7'
        b'\xae8\tO\x10\xd5\xb5\x96\xaf~\r^\x9cM}\x85\xe3w\xedalI\x10\xbaV\x14\xc5\xe4"hL\xa6\xc7\rR\xcb\x1f\x9d\xad\xbd\xe9\x12\x90\x80\xa4\xc4\x1b\xe1\x13\xaar\xa16<JX\x9a\xf2Z|\x17\xec\xaf\xb4'
        b'K\xa0w\xfe\x90\x03\xfd\x02\xc4\xb2z\x82\x8d\xd8\x91\x8a\xb8bkn\xf7\xfez=h\xb0X\x04\x97\xf6\xa0\xf6\t\xdd\x1b]B\xe7\xe6|\x885?pn\x12Z\xec\xb2\x86\x1dz1\xb9\x0f\xcf\x1cX\xb3\xc8\xa3\xb9\xe1P'
        b's\xe6\xa0\xc0\xedo\xd9\x85&>\xd8q\x89X\xf1G\xe5|]r\xfb\x81\xec\xbc/\xde\xf1\x12\xef\x18sgo\'C\x82d\xcd.\x88\x8ci\xd5\xc8b*\xac\xad\xfdQ\x9d\x89HY\xc2\xd2\x849$v"\xb8\xd9\xd8'
        b'R\x86\xe2\x85\x04/EQ\x9c\x91\x9e\xef\xcdr\xc1\x869h\x07j\xcc\xe3\x13f1\x8e\x11`\xa1\xe7\x9b\xd3G\xfb\xfd0qV<\xb1\x0fL\x7fU\xd6\x12\x8e\x99Xp\xff\x90r\x80oG\x9d=\xa8\xdc\xe6\x0bAj'
        b"\x0c\xcag!X\xed\xf8W*\t\xa6\x9d \xf6I=(\x86Y\x90$5\x81\xcai\xaeI\x06\x8c\x01LN\xfe\xe7>N'\x1a\xfe\x89an\xb9\xdcd\x95\xaa\x9e}\xd5O(\xf2s\xf4\t\xb8\xd6\xb762\xca{\x97"
        b"v\x9f\xb2\xbd\x8c\x18\xd6\xee;\xa1\xdaw\x88L#9a\xc0%=\xeeh\x1a|\xdfY'\xb9\xc2\xd0mz@p\xc8LeX\x17X\xf5p(\x953\xb5\xc5oi\xcek\x87\xac\xe1\xe1\xf9\x9b|\x9e|]Ih\xac"
        b':\xbcu\xb3\xb0\xe5\xe7F0\xf6I\x96\xfa\x93\x18P\x85\xcd\x00\x8b\xab\xc0}\xdda\xcbfX4)\x17\xc1&\x8c\xc2.\xe6\xdf\xc2\x17"\x13_\x9f* \xcb]\x02\x84\x0f\xce6\x83\xfe\xc8\xc5\xbc\x16[\xa9\xd2\xffh'
        b"\x88\x89s\x1a\xe0\x8a>\x07\xa9\xc8}\xa3\x03-J\x01\xb0T\xc5\x82\xb3\xe6\xa3R\xb5\xcd\x10\x06\xcc^\n\x9dA\xad\xc2\n\xaf\r\xb5'\x92\xc7\x11\xa1#h\x89\x11\xf6:\xa3\x10\xa5\nkZ\x01\xb8p\xf5\xfeK)\x0c"
        b']\xf7\x05vE\x89\xf5\xf9\xfb\x11jY06x\x9dHw\xefYI\xdbP#.\xc6\xdd\xcalh\xaa\xab\x01\xf1\xbb~\xa16\xb8S\xa1\xa1\x04R\xf2\x04)\xe9\xd9A\xa0\x02\x05\x8dQ\x15Y>\xfe\x86\n\xe1\x95\xa5'
        b'4\xc6\xaa\x08\xee\xd4\x1e\xd9xI%(\xc1\xafp\xfc\x1b\xc6Z\xb8\x18\xde\xfa(\x18\xae\x10\xef\x8c\xa7\x0c\xe9Rt\xb8p[\xc9\x80\xd2\xaf~YO\xfe,\ra\xdd\xa4r\x02\x1f\xa3\x1d\xa8\xf9\xc3:L\x14Z\n\xd8'
        b"e\x9a\x08\xa7\xe0\xdd\xcf\x0e }r\x9c\xadj\x88\xb6n\xf8\x0bi*\xee\x7fBdO\x95\x9d\xbc\xb8\x1c\xda\xf8\x91\xca\xb7<\x1b\x05\xb2\xfb\x9f\xc1\x892\xdf?p'\xe8\xb0\xf9\xda\xc6Z\xe2!\xb3A7\xcd\x01\xfc\xf1"
        b'/\x9f\xfb\xaaI\xa7\xa9\xe0\xdf\xc7G\x8aWR\xa3]<\x8f5\xc3#~\xfa\xe8\xad\xc2\xd3\xc0\x17\x9b\x83\x9d\xb7N\x12\xed/\x98\xefS\xc1\xc5\xf5\xfcu\xfe\xb7\r\xbe\x94\xaf\x90\xcf\xb9c\xb8\x890\x9a\x04\xd7`\xff\xbd'
        b'\xa1\xfc\xa3YA\xa8\x9b\xfel\xfe\xde\x93-k\x88\xfd\xaf\xd9\xc8\xe5\xf0\x8f>l\x9f\xea\xa8\xef\xc0\xabz\x1dvrw\x86\xe6\xf5\xb1V\x01\x11\xe6\x95\xd9Q~\xa1O\x00o\x1el\x88O4\x11\x9b\xd6\x9e\xe4\xf8P\xe3'
        b'$\xe9\xedi\x80\xa3+\x96\xc7\xc1\xe8f\xd09\xc5\x11c\x02\xb5g\xb3\x96\x16\xef\x82\xb7\xe6\xe6\xc5\xcf\x02\xd9M\x12\xb4O\n\xb1M\x95$\xde\x93`\x19\xb6u\x8e\x9d|\x17\x0bV\x07\x80\x03V\xfe\x0e\x9c\x7f\xce\x9d\xa1'
        b'\xb2\x17\x13v\xb3)\r\x8c\x8c&\x18\x99G\x96#\x02\xa1\xc1\xecOI\x96\xfc.\x0c\x8a\xd1\x19\xc4\xef\xd2\x93\x08|\xeb\x02e\x98i.\x0f\xa8b\xf2\xd0\xc5)\x7f\x91"d\x10\x10\xb40e\x1fD\xc2\x86\x02-\xafd'
        b"\xe2P\xef\xfb\x0e\xd1\xb4+'a\xc7\xd0Am\x15\xa0\r\xd2\xca\x99\\\xcc\x87\x96u\xd6\x83\xc4\x19\x0c\xbb\xa3\xd4sH+N\xaf}\xd0\xb1\x08\xd5D\xa2\x08c\x1a\x9c\xc0\x83O\x88=\xa8-}\xc0r\x89\x96\x93\x83,"
        b'\x92\xb0\xf0\xa6v\x95\xad\x04\x8f>\xf8K\x91\x1a\x83\x14\x99gr\xaa\x9f~\xb1\xd3\xb7\xcaQ\xfd\x84\xdf\xce\xf9z\xde*\xd7\x00[\x1d\xc9\xb3\x8c\xb0\xdb\xf6\xc2\x02Ud1\xc0\x17\xa1\xcee\xe8wjp\x19\x1e\xde\x92\xb8'
        b'\xdb\x06G\xce\xe8>c\xb1\xed\x91D\xe5\x80i\x11\xe2`vS\xe2\x8f\xf1f\xa7\x10\xeb\xa3\xef\x08*-\xae8<\xd8\x0eZ\xc1\xac\xb7\xc2\xff5\xf4U\xae\xed\xe7\x19\xd6\x82o\x85\xd5\xceZ!\xfc\xd0\x009\xa2zp'
        b'4R\xc0\xe4\xac\x07\x9aF\xbb\xbcs\x0b\xb9\xd9D9\x8d\xb4\x8a*\x86\xf1\x14k=@\xa3j\xe6o\xc1\xfad\xb7\xaf\x96\xa2G\xdc\x86\x82"ZK\xb3\xb2=\xf7\xfa!\xc9\xda\x0c5c\x8a\xb3\xff\x1f6\xb4v_\xe8'
        b'D\x96\x06Q\x82\xd0F_\x9c\t\xbc7RZ.he\n!\x00qPVC\xa9\x05I0|\x8f\xb4}\xf1\xd1(\xd1\x9c\x1a\xc5Tp\xe0\xb0\x1dj\xde\xd0\xack\xdb\xa1;W\xfbm\xd8\x0f^#\x8ch\x83\x83\x0e'
        b'\x93\x98\xceW\xd3N\x92/\x1fI\xec\x10\x1dV\xba-\x817:\xd6Nf\x95\x81\xb1N\xbdK\xfc\xaa\xd1\xf7m\x00\t\xb1\xce\x7f\xe0\x9f\xbal=p\x10>\x1af\xdf\xd3\x95A$\xa22i\x1bc\n\xdd\xe5\x10\xa0\x97'
        b'\xb5U+\xe3Zj\xd7oo8\xa6\xadG/HtQ\x92>r\x1b\xcd\xa1\xa8\xbb\xf0d\x98\x08\xdaN*\x8a\x98\xe2g\xd3\xa8r\xb9S\x18\x8ay\xb6\xf2\xeb\xc7\xde\xdb\r\x97\xa3\xbd\x9b\xa0\xdc;\\aA\x82\xf5\xc0'
        b"S\xb3\x8e\xdfu$\xb2\xc7XH\xd5\x12\xb4\x7f\xd5#\xc4Y\xd7+\xc3'\r\x81}\xc3\x16\xba\x07\xf2\xda\xc4\xad\xbe\xa6\x8f\xa2\x90\xe4\x13d5]\xad\\\xe5\xf6e5\xa0\xf6-\xc5(\xe4\x0c\x01\xf1\xb2\t\x1dY[Z"
        b'\x14_F\xc8\xb9\xb1\xaa\xdf\xff\xf5\x89\xe0\xb9q-\x17F\xbb\x8c1\x11\x82\xf9\x0b\x16E\x95\xefL\xdd.h\x08\xf0qXH\xe7h\x9d\xf8|\x8e\xfe\x8c\xd7\x00X\xd2\x12N\xdd\xce\x82L\xde\xd5\x8b\x80\xcd\xbf#X\xc1'
        b'5\x08\xf6\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntimeError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00'
        b'\x00r\x05\x00\x00\x00\xfa\x15<frozen fintech.iban>\xda\x08<module>\x01\x00\x00\x00s\x04\x00\x00\x00\n\x01\x14\x01'
    ))
