
###########################################################################
#
# LICENSE AGREEMENT
#
# Copyright (c) 2014-2024 joonis new media, Thimo Kraemer
#
# 1. Recitals
#
# joonis new media, Inh. Thimo Kraemer ("Licensor"), provides you
# ("Licensee") the program "PyFinTech" and associated documentation files
# (collectively, the "Software"). The Software is protected by German
# copyright laws and international treaties.
#
# 2. Public License
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this Software, to install and use the Software, copy, publish
# and distribute copies of the Software at any time, provided that this
# License Agreement is included in all copies or substantial portions of
# the Software, subject to the terms and conditions hereinafter set forth.
#
# 3. Temporary Multi-User/Multi-CPU License
#
# Licensor hereby grants to Licensee a temporary, non-exclusive license to
# install and use this Software according to the purpose agreed on up to
# an unlimited number of computers in its possession, subject to the terms
# and conditions hereinafter set forth. As consideration for this temporary
# license to use the Software granted to Licensee herein, Licensee shall
# pay to Licensor the agreed license fee.
#
# 4. Restrictions
#
# You may not use this Software in a way other than allowed in this
# license. You may not:
#
# - modify or adapt the Software or merge it into another program,
# - reverse engineer, disassemble, decompile or make any attempt to
#   discover the source code of the Software,
# - sublicense, rent, lease or lend any portion of the Software,
# - publish or distribute the associated license keycode.
#
# 5. Warranty and Remedy
#
# To the extent permitted by law, THE SOFTWARE IS PROVIDED "AS IS",
# WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
# LIMITED TO THE WARRANTIES OF QUALITY, TITLE, NONINFRINGEMENT,
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE, regardless of
# whether Licensor knows or had reason to know of Licensee particular
# needs. No employee, agent, or distributor of Licensor is authorized
# to modify this warranty, nor to make any additional warranties.
#
# IN NO EVENT WILL LICENSOR BE LIABLE TO LICENSEE FOR ANY DAMAGES,
# INCLUDING ANY LOST PROFITS, LOST SAVINGS, OR OTHER INCIDENTAL OR
# CONSEQUENTIAL DAMAGES ARISING FROM THE USE OR THE INABILITY TO USE THE
# SOFTWARE, EVEN IF LICENSOR OR AN AUTHORIZED DEALER OR DISTRIBUTOR HAS
# BEEN ADVISED OF THE POSSIBILITY OF THESE DAMAGES, OR FOR ANY CLAIM BY
# ANY OTHER PARTY. This does not apply if liability is mandatory due to
# intent or gross negligence.


"""
SWIFT module of the Python FinTech package.

This module defines functions to parse SWIFT messages.
"""

__all__ = ['parse_mt940', 'SWIFTParserError']


def parse_mt940(data):
    """
    Parses a SWIFT message of type MT940 or MT942.

    It returns a list of bank account statements which are represented
    as usual dictionaries. Also all SEPA fields are extracted. All
    values are converted to unicode strings.

    A dictionary has the following structure:

    - order_reference: string (Auftragssreferenz)
    - reference: string or ``None`` (Bezugsreferenz)
    - bankcode: string (Bankleitzahl)
    - account: string (Kontonummer)
    - number: string (Auszugsnummer)
    - balance_open: dict (Anfangssaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_close: dict (Endsaldo)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_booked: dict or ``None`` (Valutensaldo gebucht)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - balance_noted: dict or ``None`` (Valutensaldo vorgemerkt)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - date: date (Buchungsdatum)
    - sum_credits: dict or ``None`` (Summe Gutschriften / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - sum_debits: dict or ``None`` (Summe Belastungen / MT942 only)
        - amount: Decimal (Betrag)
        - currency: string (Währung)
        - count: int (Anzahl Buchungen)
    - transactions: list of dictionaries (Auszugsposten)
        - description: string or ``None`` (Beschreibung)
        - valuta: date (Wertstellungsdatum)
        - date: date or ``None`` (Buchungsdatum)
        - amount: Decimal (Betrag)
        - reversal: bool (Rückbuchung)
        - booking_key: string (Buchungsschlüssel)
        - booking_text: string or ``None`` (Buchungstext)
        - reference: string (Kundenreferenz)
        - bank_reference: string or ``None`` (Bankreferenz)
        - gvcode: string (Geschäftsvorfallcode)
        - primanota: string or ``None`` (Primanoten-Nr.)
        - bankcode: string or ``None`` (Bankleitzahl)
        - account: string or ``None`` (Kontonummer)
        - iban: string or ``None`` (IBAN)
        - amount_original: dict or ``None`` (Originalbetrag in Fremdwährung)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - charges: dict or ``None`` (Gebühren)
            - amount: Decimal (Betrag)
            - currency: string (Währung)
        - textkey: int or ``None`` (Textschlüssel)
        - name: list of strings (Name)
        - purpose: list of strings (Verwendungszweck)
        - sepa: dictionary of SEPA fields
        - [nn]: Unknown structured fields are added with their numeric ids.

    :param data: The SWIFT message.
    :returns: A list of dictionaries.
    """
    pass


class SWIFTParserError:
    """
    SWIFT parser returned an error.
    """
    pass



from typing import TYPE_CHECKING
if not TYPE_CHECKING:
    import marshal
    exec(marshal.loads(
        b'\xe3\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00@\x00\x00\x00s0\x00\x00\x00z\x08e\x00\x01\x00W\x00n\x14\x01\x00\x01\x00\x01\x00e\x01d\x00\x83\x01\x82\x01Y\x00n\x020\x00e\x00e\x02'
        b'e\x03d\x01d\x02\x83\x04\x01\x00d\x03S\x00)\x04z\x1afintech package not loadeds2.\x00\x00PYARMOR\x00\x00\x03\t\x00a\r\r'
        b'\n\t0\xe0\x02\x00\x00\x00\x00\x01\x00\x00\x00@\x00\x00\x00\xf2-\x00\x00\x00\x00\x00\x00}\n\xa4\xbe\x95\xc2\x86\\M\xb9\x9a\xeb\x870\x03\xcd\x00\x00\x00\x00\x00\x00\x00\x00\xe7\xfc\xe5\xc6c\x91\x87O\xb4\x1dmYg\xf8\x85'
        b'\x02\xde\xba\xd9\x16\x9aE\xfd\x0b\r\xe2a0\x8e\xc4\xaa?\xef\xf8\xa2\x8a\xbb\xcc\xc47\x9f>-\xa7i9\xe3\x0b\xc2.{]A=\xa5\xe2\xff\x80C\xad7\xd6\xdc\xea|\xd2\x15\x93\x9f\xdaW\x88nG\xd1\xe4\x1b\xc2\x04'
        b'\xdc?\xd9\x0bc\xaf\x18\x0bz\xfe\x82\r\xd7\x91\xdcj\xac\xbc\xa8\xe6\xee@m\x92@y\xb7#V\xe1\xdb|\x82a \xc7\x03\xc6\x8a\xc6<\x80\xbc\xee\x83\t7\xc0\x0e\xd1\x9ab\xd1j\xa25\xf0^\xc0\xd5\x1eF4~'
        b'\'\xc3\xb0\x14\x8d\xef\xa1\xcf\x83C\xae\x0f\x13\xd7\x80\x87\xfb\xc1{\xc1\x8a\x98P\x1a\x07X\xda"\xa2b\xa5\xba\x02\xb16\xfc\xd3\xd3Vy\xee\x10\x18\x15\xfe4\xa3\t\xd5\x94!@\x94US\x82\xd1`L\xa7u\x07\x12w'
        b'`,\x04\xfd\xf7S\xd8\xc4\xb6\x923]\xcd\xa8=V\xd9M.\xd0z\xaa71\xbb\x90\xb0\xbc\xeb\x86-\x17D2\x84OA\x94\x18c\xeczf\xf9`\x13xVv\xd5dLi\xffO\xaa\xdd\x8d=\x11\xc5c\rx'
        b'X\x1b\xb4\x85\xb4\xb3\xb6\x0b\x90\x8e\x15\xe9\xa9"<\x83L\xb9\x80\xc6G\xf2\xfc\xbb/\xba\xaa;\xa2\x0c,\x02\x8a\x7f:{\xfer\xb4\x83\xb2\xb62\xcb*\x9b\xea8\x93\n\x94Y\xdc]\x8b\xaa\x06\xf2\xac\xa0\x88\xea{\xa3'
        b"\x8d\xf6\xa6;/;\x07\xebN)\x91\x1c\xf4\xeb\x1f\x0e\xfb^\x9b\xed\x1b\xc8z\\K\xec\x83da\xbbk{\xd7\x8c\xdd\xad#\xc8\xf8D)~\x18\xde\x9d-\x0b\x9d\xe4\x88\x92\x15\x8f\xfd\x9b:\x05:'\x04\xaez\x1a\xbb"
        b'\xee\xd5\xe4\xe4\xf8\xca\xeb{w\x9d\xe9\x89\xdd\xc2\x13\x9d\xd4\x9a\xe7q\x9b\xbb\x9a\xaa\x7f\x0f/\x95)\xf5\x12\x0c\xfeG\xef\xf6IR=)+\x1d\x11\xa5\x9ax\xdd\xbb\xb2\xdc4\xed\x86,\xcd\x06S\xaa2\x12\x94\x06/o'
        b'\x9a\xcf*\x9c\x0e\x9c\xf1\xc7\xe1\xe0H]\x96\xbd|m\xfb\x93\xea#)AJ\x96\xc6\xa8\xe0WI\xd6\x96\x14\xc0\xe9\x1d\x97\xeeC\xe5\xde}\xd3q\x95\xb0\xdd\xb1nJ\x0eD2q\xce\xa2yf\xc5v\x9c\x06\xe1&\x12'
        b"\x1aU5o\x97\xedn\xcc\xf5|\xd3\xaak\xaf\xbe\xd0vH\xf8y\x83\xa7\xc3h\xd5\xc1=\xf29+\xe9!\xeb\x07\xaf0\xdb\x7fF\x1a\x16'\xfa\xf3\x1d\xe0Luqx\x93W6Z\xd2M\xcaUD\xf8c\x1f\xabc"
        b'\x16\xf8c\xd4\x94\xdd\x91\xfe* \x00a\xa6\x8f\xf95\xf6\xbf\xf9B\xba\x07}:\x88bYqB\xee\xa3\xa4Z\xdf\x8ei]\x1f\xba\x01\x19\xe9+G\xebm\xa6\xbe\xcef=\x83oywI|fF\xc9\xd6\xa2\x8d\xd4'
        b"x\xd7\xad\xf0\xaf\x8f\x16\xb1\xdf\x06n\xe5\xd7\xfb\xd7\xd4#\xd4\\\x7f\xf0\x8c+s\xd9j\xf8\xe7\xde\x10\xd5z\x9bA\xe8\x0e;'\x11\xcc\x11z\xb3\xb8\xeb\x13\xa5F\x06\xdfWH,\xfb\xc8o\xf4\xa2l\x9f\xf4\xf1\x142"
        b"\x91\x95=\x90\xb8\x7f\xf3'H\xb4\xbc]\xf8\x7f\xa2\xe2\x9a#,Z\x87#|\xc9P\xb3\x15\xb1}\xc6\x9aIO,O$n1\xa6  \xf6\xee\x91\xb5p\x1c\x0c\xc1\x0f\x9b\xa7|GF\x8d\xfb\xf6\x97(X\x7f\x0bE"
        b'V\xbd~\xc5(\xe4i\xafb\xa5\xf5003\xd5\xa8LbSO\x18\xb9\xc8\xfa\xb4p\r\xd1\xe6y\xa1\x01\xb3\x10q\x0b\xd4Ri\x96\xc8`\x83\xbc\xe4\xc7\x1b\xb8\xd9\x01V\xaas\xe7\x80\xf4\xf3DJe/:#\x83'
        b'\xb2\x94\x04\xa7x"K\xe9\xe1N Tm\x84\x01\xd3^8"\x16\xc8\xf4\xb6\xcd\xe9M5-\x9e\x15\x87\x1a$\xd1\x97\x15\xa9+\x91\xb1,h\xe8\xa82\x94@ (\x1e\x94\x0faeO\xa0\xd3\xbd\xe46y\x19\xf9\x87'
        b'w\x19S\xces_\xbf\xa0\xa2\xb3rp)\x166\xd1\xf5\xe7\xbc\x81\xa0r\x93(\x8b\x80\x95\xbc`\xc4h\x89&\x0f\xc9L\x98w\xde\x14\xff\xcb\xe6\x1b5\x87pUG\xd7\xe1\x0c\x07\x03Tp\xf9N\xb8q\x17\xf5\x9a+'
        b"\xe4\xfe\t\xa6}1\xc4'\xe9V\x8b\xee\xc6\x8a,~\xe9\x90\xaf\xc0#q$\xa3A\xc5o\xec\xb06k+\x163v\x1b\r\xd6\x12\xf1\xffN\x85(\x00\x16\x15`lR\x19\xff\x84|\x90\xe6\xaa#?\x91\x10\n\xde\xec"
        b't\x98\x91\xb4\xe61\xb1{t\x07\x92\x8d\x14\x06!E\xdc\x1d\xa1hA\xae\xd3\x9a\xcbq\xdd\xcf\x15\x0b`<\xcd}\x07\xe9\x92\x03x\xf5+\xa8\x96?\x95\x08\xab\xd2\xb4\xbb\xf7jN\xcbmx\xc7Ji\xa8\xd5\xc2\xa0c'
        b'"\xb4\x1au\x81@\xfb}\xf7\xc3\xfa\xcb\x06\xa2Z\x1f\x05Y-e\x90\\\xc4n\xc5\x0c\x8e\xe7\xd8B\xfe\xdeW\xf5Y\xb8\x84\xa0\x12\xa8\x0c\x1b\x8e\xff\xd4/\xc1\x9f\xd4\x84;\xa8\x8aj\\\xd6UTSM\x88w\xdcm'
        b'5\xdf{\x84\x8c\x86<\x07\xfd\xba\xce\xb5\xc5\x9f\\n\x0fL\xf7\xf6?\x18\xb0\x93\xd2\xcdb\xa2\x8cjrn\r\x9b-\xd7\xc8P\x9e$*R\x14\xfd\xfe\x93Y\xfd\x87=64\x01\xd2m\x00\x872\xd8\xfc\x14\x012o'
        b'\x00\x91\x96m\xe5\xb3\xbe:\x81H\x18!\x10\xae`\xa6{\xaep\xf7m\xc5\xa3b\xff\t\x16\x1evh\x8c\x15K\x8a\xd0\xab@^\xcf\x0c\x95\x81v\xbd0z\x01_\xc0\x19@\xf26\xbc\xc6\xfdL\xf8M\x1c\x95\x80H\xe1'
        b'[\x08brV\xf1\xbc|\xa6\x9b\xc2d\xe2o\xac5x \xf1\xc9\x9a>v\xfb\xd9\xa0m\x1d\x89\xdc/\xdb\x1f\xf5\xa2\x15\x13\xa0\x95\r\x1an#z\xda\xfc\xab\x93\xee\n\xc1\xf2\xed\x89,\xa67\x1f\x13\x1c\xf0Z\x15r'
        b"@W\xc9\xe9\xd4'\xb2\xce\xbc\x1ef\xde)\xe4\x918\r\xc8\xbd\xc0\x04\x0c\x94e\xc9\xa3\xda\xd4\xe5O\xd8\xf8\x0f\xb3\t\xbc)AbJ\x1d\xa8#\xee\xfa\xdc6\xe5\xc4\x81#\xd3\xe6j\x94g\x17\xc4\x9a_T\xdar-"
        b'\x81\xcb\xcc\x0e\xa4\xb6\x9f1U\xdc\xafO\xd2\xa15sS\x85\x92\x99\xa8\xa1\x90\x0c\xafH\x1cb+\xe6n\xcf\xd5\xf0\xc8l.\xf8\xdcq\x88\xf1\x8bl`\x04\x0f\x90\xbe.u\xa6\xcd.\xb7+\x08\x0f\x91\x86[\xf0\x91\xa1'
        b'\xb1&t\x1a\x8e\x13o\xb6\xe1\\\x92\x1au\x01\xa4\x11S.\x1b\xbfG?[\xab9\x9dFX\xad\x96\xfcl\xdd[\xaf\x07\x14\x8dDl\xfa\x8a\xf2H%=\x1e7\xc7\xae/<E\xda\xef\xc9\x03EU\xc8_\xf3\x8e\xbd'
        b'\x0cz\x82\xf5a\x1aI\xc5Cg<\xa0\xccmg\xf9J\x9f\xf2\x83\xd7\xed\x1fL\xbe\x10\xe7\x0bR\x83j\xc8\x1f\xa3\x93\xb6\xb5\xe1%\xa0\xa2\x0fP\xf8\xe8K\x94+\xb1\x08\xbf*g\xb9\xbe1Ak2\xb6\xe50n\xaa'
        b'\xca\xaf\x17\x81\x1f\x1f"i\xeb\xa2\x00:\x11\xdc\xd1F\x8e\xb9\xa4\xfb\x12/\xb5\x94o@\x9a\xb7\xc0\xa8\x89\x8e8\x8e\x98~\xd4\xe1K\xb3\xbe+}\xf1U\xe6@ga\x07\x12\xa3\xe9\x7f\xd2V\x9e\x17\xb1 \n\\\xd7\x9b'
        b'\xa1\xcex\xb7\xa5\xa9\xe90\xa0\xde\x19 \x84\xb8\x85\xe2/}\x83\x82%\xf8kY;\xeb\x91L:Pf\x1c\x8eT\xbb\x01\xd6\xed\xea\t\xb8\xc5\x84\xad\xb6\x8d\x19\xc1\x1cUsM\x08s6W\x86\x96~\xde\xaf\xbfE\xcd'
        b'\x07h#6\xf8\x85f\x9c\xe1\xc2\x94\xf0\x8b\xe2\xfa\x97\xf2\x8e\xa2w\xe4\xbb6\x92\xeb\x97\xb9<\x8eN\x1c\xf2R\x84\x03e\xab{u\xcf\xe9\x91\xfeb?\xa5m\x94\xe91\xbde\xa1\x10^\x8c\x18\x11\xe5\xcdEX\x1d\xa9'
        b"\r\xb4[\x85\xeeg\xee\x8dyf\xe0\xf0\xc2\xcf\xaf:F\xac\xdc\xbb9kK\x8f\xe5\x8c'U\n\xf6\x06\xbbR\xf3\x99+j0tQ\xc40v)\xcey\x05/;[\x93\xf0E\xbd\xa6\x1a\xe3\xee\x0c%o\xd5>\x9a"
        b'\xc2\xd8\xd3\xf2l\xf0m<\xb9z\x151B\xee\xae\x994_\x876\x19\x93G\xd3Jw2\xd0\xdf\x9d\xeeW\x08\x8fch\xa7\x89\x8e\xec\xbb\x99\x7fb\x0c\xa3U\x82\xcb\xd42b.\xa7H\xab-\xbd\xe0H\xc5\xa9X/'
        b'\x07\x9e\n\x9f\xa72\x9f\x15\xdb\x85\xd4\x82t1\x9b\x83\x0c\x82\xadeS\xa3\xae\xd7\x1b\xda\x158\xa5v"\x91\xffC5j"\x99V\xb0\xd0\x8c\x03i\xf2u\xc9!\x08.\xc3\xfd{n\xbc\xc4\x11\xee\x02\x1ddVd\xb7'
        b"\x0f#\x80\x06\xa2\xfe\x96\xcc:4\x14H\x84\x17V\xdc\x9e\xe7\x1f\xdb\xf3Th\xb6S\xd1k\x8c\xed\x80\x83\xa7\x8b#u\x14\x95N\xe6\xa9\x07\x1cf\xa2'u\x909\xa4\xf7\x05k\xf3\xf35\xcd\x1c\xad\xd1\x95\xebUR\x0c"
        b'\xe2\x906\x85\xa6\x18\x1ca\\"y\xf0(\x11\x7f\n\x94\xd75w\xbb\xbbo]\xe1\x80\x10{\xad\xd3ml\x86E\x87^\x15\xf7\xeec\x85\r\xc4\xed\xbd\x1c\xb4\x8e*\xbc\x02\x9c\xca\xfd_\xb5T\x92{WK\x13j-'
        b'>\x9dh\x98D\xc3%{\xb9\x92\x93\xed\x80\x18\x91\xbbU\xc0\x91\xc2+\xb3\xef\x97\x08\x03{\xfae,\xc6\x94w\xceIq\xcf\x19u;\x1cxc\xae\x1c9!\x96\x9e]\xce\xb3l\xb5\xf9\xb1W+q\xa9P\xadZ\xc7'
        b'\x12i\x17,q0\xb5h\xb9\x93(\xb9\xef\xed0\xfa\xeeZ_\xc9\x88\xf3;\xb5g\xc4\r\x1c\xac"\x00\x8b\xc03\x9c\xc6H\'\xac\xce\xcf\x88\xfel\xdb\xc1^^IGT\x7f\xd7\xf7\xf3\xdbC\x88\xb5\xaa\xd6\xc84\xec'
        b'2m\xcb\x8fU}\xf6\xb9\xa0(\xab}S\xd8\xcep\x10\x11\x8aU=(\xaa\xaav\xf5g\xe6\xe2\xc0xp\xdf\x94\x1c\xe4\xf82\r\xae\xd8&\x8f\xad:[\xcb\xce\xf2\xfan\xfe\xe3\xbfjL\x85\x17c\xfc\x96#\xc8\x87'
        b'\x7f\x16\x8d\xb3\xab\xa7\x06!5\xf8%\xaa\ni\x0ex\xf4O\t\xcbnQ#\xbd\x86Wz\x9d.R8\xaa\xdc\xee\xbd\xf6\xf5\x98\xed\x81\xf0\x8c\x97\rO\xea\x8a\xf8\xd2kl\x05\xd8\x8a\xa9\xe1\x10,Y^\xb6\xfb\xcb\x99'
        b'\xda\x87Q\xe7\xfd\x9a\xe2\x99\x9e\x0c\t\x04\xe5R2\x94\xc5"&\xa5\xf0%R\xca:G\x1a\x9e|<\x00B\xe1[m\x7f\x9d\r\xbb\xb9\xf1\xbb\x08>N\xf2\x07\x98\r"2\x1269|\x89(\xa4\x8f`\x0b\'\x16\xb4'
        b'[\x00G\xaa\x93I\x95\xacV\xb1\x03F\x89\x19pv\xbbv\x12\x9f%\xcd\xa4\xc4\x89\xd6\xe4\xbcJw1{i\x83\x05\xa5\xaa\xac\xbc{z\x8b\xa6\x15*\xb0\x84FL\xa8\x7fIN\xba\x0b:N\x9cU\xa1\xe4\xb1\xa5\x9b'
        b'\x97\xd0\xae\x8e\x1a\x89z\x1da\x893\xf7=\xc2\xfc\x00\x8a\x80\xbb\x0e\xe0\xa1\xcc\x8b9\xdcm\xd0%\xbbN\x8d\x8e\x01\xd2W\xb2S\xd5\x15\xe4\x1c\x92\x8f\xa1P\x10w\xc5\xe2\xab!\x8b\xbd\xbbkW\x1c\xcb\x01\x80\x12D\xf6'
        b'\xc6\x98\x80\xf4\x7f\x87d\xbd\x89\x13-\xd3\xcf\n\xb4r\xaf\x8b7\x0e\xe9=\x99\xf1\xad\xa0\xea\x0e\xed\xf3a!\xfe\xa8\xe7l\xf8\xfb\x873\x07G~a\\\x7fR\x93\xedQt\xf4Z\x15n\xfeE"\n0"\xd3\xbdD'
        b"\xa2\xa1('\x97\x03\xebw\x85\xdcn(\xee\xde\xbea\xab-\xcax\xa9)\xf6 \xf4\xcc\xaa\x18\xf8\xd7\xba\x81\xfd\xc4p?\xdfkP\x06\xb4\xff\x9a\xb1\xcb'kH\xf3\xe1;\x1d\x08\x15^\xabO\x15\xb67( v\x04"
        b'|\x01p\xc4\xb66F\xb8|c(\xb9\xe1\xf8\x8e5pJ\xd7\x00\x83 h\xd7\xb8\xe5A\xfb\n\xe2\xfe %Z\xd9\xf0|\xa6\xd57l\xeb6;\xc7\xbd9\xe3D\x10\x0b\xb7C\x19\xa4\x13A\x92\x83K\x91\xdb\x01\x96'
        b'\xc2+\xbd\xf4*\xdc\xdf\xf0\xe1\xac\x9f\xedKT\xd2s\xa5x\n{\xc2U\xcc*\xcbk\xf0\x01\xeb\xcex7\x1f\x13\xe1\xb8\x97\x98\x10\xb9@#\xc9SIV\x02ziT\xb5-\x81\x049C.a\xb2\xd1N\x1d\xcb\xa3'
        b'\xef\x1d\xdecw/\xef\x8e\xc4\x90\x87}\x8c\xdc-TE\xebR\xf4O\xd2\xacCs\xf2q\xed\xafj\xa4\x06\xfd\xb9K\xf2\x81\x103x\xe9\xa7\x1ba\xdb\xd2\xae\x9ba\xe8x\xffd\xba\xff\x16\xd25\xb1\xd4b\x85\xd4S'
        b"\xcb\xc4\xa3h\x07\x81\xad\xd9R\xb9\x04\xbb\xbaT\x91'\xce\xd5\xad\xb3B\x8d\xfdUq\xc4\xeeG\xe0a\xa9\xf8m\xd5\x06,U\xf3\x87\xd5\x82\xeaodL\xcb!z/\x81k0\xd1\xfd\xb1\xbb\x10(\xe7\xefIg\x16,"
        b'X\xa5+\xd9\x1am\x98c2\xee\x00\xce#+\x9b\xa7p\x1acaM\xbc\xa6(\xa1\xe2\x1a\xc9\xf5\xc0\x96V\xdap\x0b,1a\x91{4\xb87\xbeL|n\xcb\xcf\x95\xe9h\xf3\xd13B\xe6\x02\xa0\x03\xe8\x01\xc14'
        b'7\xe5\xae\xf3,\x05s\xaa\xb3\xd4|Uv\xba\xcc\x1b\xf8k\x8b\x81\\D\x12\x06\xf2\xa4e\xd5\x9e#\xbe\xd8\x8d\xb0\xae\xb7\x8d\x08\xac\x846Or\x0exB=&\xe9\xc5\xfa\xcfov\xbf\xddtd\x1a\x01\xda\xd4\xb1Q'
        b'ju Y\xb0\xab\xc7\xe4\x01\x89\xa2\xd0K\xfc&is\x9c\xd6\xc7C\xb2\x9d_}P\xbc\x07Y[[h>Z5\xe0\x8b\x1d\xef\x93gS\xce\xd8\xff\x9c!\xa7\xca\x07\xe8\x0e\xdd\xafB\xc2\xf7\xdb\xa8\x99\x1d\xac\x02y'
        b'`\xb7\xf5Qu$\xc9\xbf\x89S\x97\x92\x07\x80hsE\xaeG\xc5\xbaKc\r\xc4\xfc|\x04\x86\xd3L>"&\x80N\x0f\xbe$\x8fC\xa8x\x81t\xa5,R\xef\xdd\xb3\xae\x08\xe1\x9b!\xb4\xa1c\xc5L\\\x07~'
        b'\x1fIP0\xf3$\x0c0\xa3\xa4*\x15ZY\xb6\xac\x9b\x8a\xee\xae\x0b\xac\x0b\r\x95\x82\x83py\xe6n\xf8\xd3\x10T\xf9\x81\xf6\xaaB\xbdD\xe9\x04X&\x02\xca\xaf\xcc^\x16C%\xca\x04h%F\x866\x8f\x0e\xc9'
        b'\xc68\xff\xbf\xecf,\xe2w6\x02\xc4\x86\xc1\x03fzf\x01Q5\xdaIN\xb8$@)A\x07l\xf1\xf6\x7f\x11\xec\x9c\xd6\xf2\xc3h\xb68\x15\xe7Q\xf6\x83Cj\xb1s\xfe\xc0\xa8\x92\x83\x8c\xd40\xb0\xf2\xe2k'
        b'\xdc\x1f\xb8"4\xe0TG\x9b\xd2&NKF\x06\xac\xd4\x86\xa7xa_6X\x943\xa5\xd9\xec\xf7\xbf\xcc`\xe3~\xbc/S\x9fM&\xdd:\xb5\xea}Qk\xd2_m\xcd8\x04\xe3*\xf8\xde\xbc!\x89\xc2\xd3 '
        b'\xb2"\xde\x97\xa1\x9eX\xa1\xd3\xa2\x7f\xbe\x00Z?\xf1\xe6\xc2HK\xec\xfdZ\xb0+\xe3\xa0nmo\xd9\xd3\xf9\x83n\x95?nG\x8a\xc4\xf4h\x17j\xc9f\x95\xff\x7f=\x0c~\x18\xfa\xc5.\xf5VC\xf7\x82q\xa8'
        b"\xc2A\xb2\xf4.X\xdf\x01x\x8b\x1e'W\x11\x95\xd6\x01\xa3\x91\xe4Z\xdd\xe9\xa5\x1b\xf4\xab\xc1\xed{L\xaauDa'\xc5\x1b\xa1Oq\xd7\n*l\xeb6Pd\xdc\x89\xbf\xc7sv\xfe\xa0\xfc\xeehD\xf8\xf4\xb7"
        b'\xf5\xefq\xd6q\x1a\xe5\xe8g\xf8\xbf\xef\x9d7n\xbcS\x97\x17\xe6\x8aH/2uzm\x95\x1e\xbd}\xb2\x90\xe4\x9b\xcaV\xd3%\x80\x17\xaaJJ\x06\x90\x0eV2\x1d\x98\x05\x8ei\xc4\xf4w\xad\xef\x9e\xa6\xf7\xeeD'
        b'\xe8U\x11\xe4\xa0\xae\xf4\xf53\xc9g\xbfN\xfa\xb7\x96\x8b\xa6\x06\xc2\x15\xda.\xc1\x8fJk\x11R\x893\xe5\xbf\x0b\xcb_y\x17CN?\x83"\xff.\xad\xf7r\xab7\x97\x9f\xb9l\xa6j\xb6\x85\xff\xe0~\xe7Nu'
        b'3G\x91XH-\xeat\xfb\x8e2st\xbb\x97\x9b\xdb\xbfE\xc4l*\x9f\'\x93\xa9\xa40\xa6\x7f?*pj(N\xb1\xeba;\xc0%"\x02\x96t\xc5\xf0\xea\xbdJ\xcb4\xfd<\xe9\xf41\xd8\x85a\xee\xd6\x0f'
        b'>L\xa4\xd8\xb2\xbd\x8f\x9d\x915H\\"\xee\x08\xd0p%\xd3\x9a\x10\xcctCPz)~+q\xd2\nR\x85\xbc\xae^\xd2\x83\xcb\t$r\xd2\x88\x13=\xec\x1a\xd1\x1d\xbe\xda\xc6\xb8\x86\x98CC\x90\x19\xfcGy'
        b'ebx@\xbe|\x13\x18H-R\x958\xae\x9a3\x9e\xcc\xd6F\x1bE\x9dR\x94\x8d\xe5\x10\x86r\x17Ha\xd8\t\xa8\xa9\xf88g\x87+\r\x16\xe0;\x81\xbe\xb76|\xf6\x82\x1eI\x12\x94\xdbsA\x0e\xc51\xf8'
        b'\xe84\xe8\xa3\x05L\x1e\n\xad\xe2=\x8e\xe1\x12#\xe0\xf2\xc5VgR\xda"z\x8cu\xcakC6\x13c\xfa\xe8\x1aM,\x861\x16\x1d\x85[)\xa1/\x05K\x02/\x1b\x14v\x1a\xa3\x8b\x00&>\xa8\xccc\xb2\xe4'
        b'\x14\xb3J\xe6#\xb6\xf0\x85\xbc\x86\xf1Q_\x8a\xbd\xdeY\xdd03\xff\xa3\xd3\x0b\x14\x8a1j%\xeeC-\x7f]\xf1\x1f\x81@\x01W\x8e\x9f/\xa3k\x899X\x03\xf6XLWpt\x91\xdb\xe8\xc9\xd0)<@\xbe'
        b'\x19\xe4b\xaa\x12T\xe6\xda\x10\xad\x89}\xdb\xc1\xab\r5\xd7\xe1\x9c\x90\x14\x1f\xc2\x8b\xbc\xdcH\xa2,\xc0@\x89\xdb\xad\x82!\xc6\x86O\xb1_\x17-[\x04\xfa\nb\xe8L\xb8\x8fR\xf4\xa4-\x10\xa6\xdc\x7f\xec\x85y'
        b'-\x87\xe8`\x93\xe7\x84\xf0}\xd6\x8f=e\xd2\x18\xa1\xf7\x12\xfb\x88\xf4\xc7\xf21\xda\x8a\x93\xee:5\x93\xa1+*\x80\x8b\xdc\x00\x0f\x1b\x08\xeb\n\xaf2m\xf5\xc6\xe2\x16\x01\xe6G\xafVp\x93N)\xd7I\xa7\x89\xf6'
        b"\xc4\xeb\x88\x99\xed\xce\x10ho\x16_\x10\x9e1\x89\x0e\xa0P\x97\x00\xd2\x84\x1b\xde\xfc!^\x9c\x01~GC'\xf5\xb0\xbeo\x05\xd1\xa1\x89\xc88c\xe2u/\xeb\xd6th\xd4\xbf't,\x02\x86\x18Zo\x12m\x8a"
        b'E\xcb\xa3\xe2\xac\xc4\xe8`\xe4\xe2\x13q\x1aj\x8b\xc7+\xbd,C\xe5$\xb2\x9d3\x9d\x94+F\x03vi\x85\xb9@.\xb1\xdbe\x07E\x90\xe0\xbf8\x9bNmE\x15\xb9\x06#s0\x8a9\xef3\xc8\xa6p\x12]'
        b'0\xd3J\x0f\xcdP\xcb\xfc\x02\x941\xc2\x98e\xb4\x16\x93\xa6\x1d\x93\xe7\xba\xdc1\xcb\x9dq\x0e\xd8\xf1\xb4\xc2b\x1e!o\xc1\xcc^S\xbez\x9b\xd7\x8f;\x9bM\xb3\x05kv\x1a\x925\x0b\x12\x10_\x7f\xf0\x9d\x8a\x86'
        b'&x\x95\xb6sk \xfd\xe1|\xa1\x0c\xce\xcf\xa6E\xfa7: \xf7\x02\xcd\xf7\x04\xba\xecy\r\x88\xd3\x82\xcb\xa6\xe7\x7f\xef\xd0q\xae]\xde6\xe6\x03\xf0m\xa2\xec*s\x0b\x7f{\xdag\xa8s\x07\x1f}*\xa3l'
        b'\tA\xf6\xf7.\xd7\xe7\xdb\xba`4\xba\xe0X\xaa@1c\xc3\xdbW\xac\x13\xda!:5<\xf6\x1f\x1cY\xef\x1ei\xe1\\\xa5\xea\x930B5u\x17^\xd5H\xf1\xc20.\x86\xeb\x8a\x12NG\xe9\xf1\x02\xfb\xc7\x84'
        b'\xec\x8fi9\x1c\x7f\xb7\xcci\xdba\x1bmP\xf5\xe4\x06\xf0\xe1)\x1c\xe1\xbc\xe5 \x8f\x1d\xf2\xc9j\xec@w:mb\xee\xcc{\xca\x92(\x18\x0f\xediTs"{\xf6\xf4\x0e\x0e\x1aM\x98"\xe3\x7f\xbb\xad\xef\xcb'
        b"\xca\xf5C\x90\x8e\x89\xafRK\x9b\xc4a\xef\xd3'+d\x18li\xfc\xac\n\x96\x8bB\xcd\xd5Y\x18{\xdaP\xe4\xf3V3c\x06cM\xeb\x88z6\xe8S\xac\xe5=zrh\xb8\xe8p\xa8W\xcao:\xd1\x9d\xa6"
        b"\xd2\x11\xc6BG\x8aZJeF\xa6'\x8ar\x7f\x1eJ\x91lx/4\xaf\xeaS\xf7\xcb\xaf\xfd\xfa3\xc7\xe4{L\x1d\xb9\xd5\xc8\x11\xf3$w\xf2MMvx'\xedG>r\xb4\xc6$q\x10T k\x8cC\x1d"
        b'K\xcf/5\x0c\xcaw\x1c\xd7\xfa=a\xde\x98\x0e\xc3\x11\x93<\x81v\x15\xf8\xb1U\x0c/\x04<)\xc96\x86\xf3&v\xceJ3c!E\xc2,\xf2\x87Q\xff\xb9\xd1n\xfeS\xa2\x8b\xda8\xfeY\xdd\xf7\x18!\xd2'
        b'`\xb5i\xfd]f\xc8\xfe,\xd6\x81X\xaco\xe3|\xc6V\xcep\xc4\xbd\x80s\x8e\'\x81<\x8f\x1f}\x98m\x13\x15\xe0\xc7\xd4\xa3\xa5\xf1\x8bX\xa5\xa9\xa2^\xa7V\xf3\x89z\xbdty\xe1.\x02\x88"\xe2D\xf3\x96'
        b"\x14\x0e\x8a\xeb\xfa#$\x19xM\xf4\xcfBf\xbdAP \x91\x0b7GV\x1a?\x1e\xe9+\xcb\x07\x913\xcb\x81AO\x0f\xf7\xf4$\r\xc2\x06\xcbN:\x0b\x81\x88'8\x91\x9e\xa1q\xaeh\xdfR\t\x80=\xff*"
        b'\x0b\xac\x9c\xa5\xcc\xca\xac6\x9f\x06\xb6K\x00%\x82\x05L\xf0\xf0\xa8Jz\x0e\xa0\xf92rt\x82\xde\xd7\xef\x9c\xe0\x94\xdc\xe4\xa8\xb4#|\xbe7&\x0e\xcdL"\xa11r\xc0e\x1d@\\\xc7\xd9\xadO~\xa2\x12)'
        b"\xe42{&\xec/#\xb6\x9f\x99\x1f\xe5 m\xa6=\x15\xc4\xe06a\x8er\xb4\x15\xe9\xaf\xf8\x08\xc3\xcb\x0f\xd9Tx\xa8\xc9%\x94`\xa2'>\x8e\xcb\x03M \xffL\x9a\xe6\x99\xe5w\x8c\x1b\xfe\xd4\x04\xcaC\x17\xdc"
        b'\x83\xad\xb1\x95k\xe4\xb3^\xab\x0c\x16\xd79\x06\x15\xb8\x98b$(+\xfb\xc5\x95\xd4"g\xffA_b\xaf\x7fMV\x1e\x8a\xdc\xd0\r\xbd  \xce\x8e\xa3\xfc\xad\xbe\xa3\xfdM\x82\x04\x12\x14^\xbcP\xbf\xf5"+\x03'
        b'\x97\x9f\xfe\xee\x02pz\xf4\x12\xa9\x9c\xe2\x84_\x88C\xf6\xda\xc1\xa5\x14;P\x11\xc3il1@1V\x10\x96i\xef\xc9\x18zH\x1b\x88\x05\xf6\x91\xb0k#\xf6\x89tg8:p\x87\xa2\x07\x9e\xbbx\xa8`\x85\xec'
        b'=&z\xc3\x16\xfb\xd5L\xb3-\xd8\x991\xe5\x1eXy\xce\x9b\x9e=[q\xd7\x06\xb9g\x8e\x80\xb7FQim\xa2]9\xa22!\xde\xde\x88\x08\x13\xeeV\xdf\x17\x90XS1KP\xc1M;\xef\xa4\x82\xbbq\x86'
        b'n)\x978{\xb7\xf2X\x9a\xd32\x94v\xd5;\x96\xaaz!\xfe\x06\xd6\x99.\xa2#n\x18\xe1d\x96\xc0\xf3\x84\xf4\x8bG-\xc8\xa3^\xdcG\xbc?\x825x%d\x01\xac\xcc\x05S!\x1e\xf21\xf1\xb1\xe8\x84\x12'
        b'T\x83b\xe7\xa90\x8em\x07\xb9\xa2\xdf\xbe,T\xb4\x88wu5\xe9\x12\xb2l\xd0\x0b~H\x8f\xe3y\n\x9a5\x8bA\xf4\x1dqH\x80\x88\x87H\xa2\xcd~u\x91:B4\x8f\xbb\xf5\xcb\xd2\x92P\xa6\xc7?\xc3\xb8'
        b'?\x03\x08-\xd9\x12v\x02\xf9~\x90\r8 \xf9\xd7\xbb\xd9\x1cn\xbe\xef\xd7\x0b\x9cD\xf1BB8IWm\x8d\xae\xfd{\xba\xff\xc4M>9[\xca\xc6\x1eb=\xb1p\xf3H\x88$8>"\xf8\xf6q^_\xd4'
        b'\xf8\xd4\xb4-8\x9a\xdf\x17\xe4M\xd8O!0V\x1c\x06{:d\x1e\xfd\x10\x8d\xf2\x88f\x97\\\x87"\x82&\xc7\xc8|\xdf\xbe9\xe9\xaeA\x84\xb8R\xc8\xd2+0\xe1\xfbp\xddA\xac\x00\xba\no\xc91~u\x10'
        b'9(\x08y\xfd@V\x10\x9ar.\x12\xce\xd83\x07\xfb\xb5\x18\xa2M\xb9\xdd\xc6A\xa3q\x95\x8c\xabx\x05\xd9\xe3d_g\x8d\xe3\xc6\xfe\x18\x04\x1b[\xff\xb5\x9c rJ\x05\x074\x17\xb3\x1f\xd2\x84\x8b\xa2\x0c\xfb\x85'
        b'(\xe0Bp\xeddk\x85\xf5X\xe3\x9b\xf7\xd6\x025\xfd\x0e\xb061\xd2\x00\xda\xda)\xacSA\xcb\xc9\xb9\xbd\xd4\x94\x04\x98\xb8\xed\x8c\x9f\xcd\x85ac3\x1e\xfd\x8eo\x81\xd7\x1f\xad7\xd0\xaaM\xb4id}\x8e1'
        b"\t7\x03\xdd\x1b\xc4\x0b1\x8a\x1a\x97\xe4\x16:\xbdbY\xaf\x1c\xba\xf64-M\x18\xaf\x86\x12d\xa1O\xff\xe7v\xde3?0\xa9\xcf\x02\xdb\xbd\xce\xaa'\x98\xa93\xec3\xd0\xac\x95v\xd2\xbfT\xcb\xa6y1>\x8c"
        b'"\x15\xd0\x0eIZ\'l`\xca$<4f\xb8\xb4\xea\xbb\xf1\xb6\x13\xa3\xbc\x914\xee\x8a\x8f\xf7\xb1\xbap]\x17d\xba\xafB{\x9bta\xa4d\x84k^\x9b\x97\xa9\x98\x9d\xd2\xf6\xed\xabR\x00T\x08\x113\xad>'
        b'L]\x1f\xff\xfb\x15\xe1\'\xdc\x0c\xd9\xb7\x7f\xc6\xe3Tot\xbe~Z\xe4\x00\xca\xb46\xb4"\x9fe\xd9\\h\xe9Y\xbbL\x1b0\x94r\x06\xa6\xd6\xa7mU\xbc\x07\x9e#\xa7\xf4\x91\xfaG\x86I=\x03~\xf3\xe5\xf9'
        b"?N\tZ\x13\x99\xa8\xef\xa3\x9b\x88\xcf\xa8\xf84\x16\xdcQ2\xaa4\xba\x92C\xf6\xafX\xd9!\xd0\xa3f\x98Y\x1dJ}\xf8_\xd9Y\x08f\x88\xfdj@'\xf5\xacw6\xea\xe5\xe5\x8f\x02\xf7X\x02\xbb\xdd4m"
        b'\x1c6E\x98"G\xce\x89\x8e\xba\x05\x13\xf2\xd6v\xe6S\xd1\xf2\x08f\'\x9e\x9ev\x9d\xc08\x87IK\xe7\xdcI \xf0v\x99\x18C\x1d\x0c{\x9d#G\xc2\xb2Q\x9f\xf3\x85\x07\xbb\x19!\xa3\xce\xa23s\x9e\x80\xa3'
        b"s\xcd\xe3*n\xf7\x98\xe3nT\xe2;\x00e\xf1\xc9,@\xd1w\x1e\xc6V\xaf\x10\xc5\x95\x08\x89\x87\x81\x83\x8e\x04(\x1f\x9f'\xb5\xab\x91\xb2\xcb\x16\xa3y\xde\xeci\x0fOp8=`\r[\xe2\x96\xa1\xfd#y\xc3"
        b"\x12\xad\xbbp\x86\xdf\r\xeb\x17Ky\xf5\xd8\xcd\xdf\xc0\x9c\xa9\xc0\xb7QHkI\xa7[\xe1\\\xe1g\xee\xb8\xef\xe5\x0b\x12'\xac\x05\xe3\xac.[Z\x858]\xa2\xce\r\xb4\xf4'<\x1dP\xa3D\xdf\xe8\xbf\xd0\xb0W"
        b"\xb8Zt\xe7\x87@\x10a^\xe7~'\x0b\x01\x91jk\x8doI\x8c\xdb\xbc\xb27\xae\x9b\x06m\x88\xde\xd7\xd9I\x97tA\xea\xfd\xc6p\xb8\x1fF\x1aa\xf6.Q\x99YO\x93q\x19x\x17:\xb0\xb8`ta\xe6"
        b'bF":\x83\x8d\xaf\xb7.\x0eJ"\x02$}Wg/\xd1\xd4JM}\xb1\xeb`\xd5E\x16\x80\xb0\xaf\x82\x19\x04jS\xdf\xd4\x15\xd9\xe0\x97u\x85-\n\xda\x86q\xad\x83[M\xe1|\x81|\xc3\x16\xad\xc0\xba\xc6'
        b"\x1f\x17\x02'Q\x05\xe0\x97\xed\xf2\x1d\x97\x0c\xd6\xcec\x08\xbf\xef\xe7\x9c]\x91\tYPX=\x92\xe6\x00\xba\xb8\xf2\xafQo\xf1\x02\x82\xce\xb9\x8b\xaf\xf7HF\xc0\x0bx\xc8(\x9b\x90\x11-`\xc4\x9e \x83D\xe6q"
        b'\x80\x98cP\x81\xd0Y\xf7\x81\x80Xl\xbd"RdG>\xf8\x0b\xd5o\xb7\x1a\xcbe\x03\x06A\x1f\xc5\xaf\xc6X\xc2\xe6\xea?_\xba\nAYC\x80f\xbf\xdc\x1a\x85\x11\x90\xfb\xd0Z\x1c,V\x0c\xd3`\xfc\xb2\x15'
        b"\xd9\xfb\xc7\x08\x95\x16\xe3\xc4\xd8\xd0\x9e\xf6\xec\r\xe1\x12\x8f\x16$\xb7!\x8a\xe4\xb5\xf7AK[H\xdd\xb31\nZ\xa0\xedlJp\xd3\xe5\xb2\x18x<\x06\x9f\xe6u\xe7\xd8'0\xe0*\x1e\xb0+w\xe2\x99\xc1\xcf\x86"
        b'K\x99R\x9cq\xa0\x88\xe5;\x9d\x1c\xad.\x80\xac\xed\xf7\xed\xdeR\xbb<n9\x01\x0c\x9ae";\x9f\xefZA\x9a\x1d\x1d\xfa\x986\xec\x10\x89*\xe7\x982\x87\'\xe3},\x86\xa8\xc6\x1e\nZ\xb9k\xbd\xcci\x12'
        b'2\x8a!I\xa0\x86\xb5\x9cuq\xea\xcf\xfa\x90\xd5_\x1a\xb7\x9bxc/\xe2\xe4K\x81\n\xd6HKf\x97Fv\x9a\x96mK\xf6\x0bf#\xa8\x96%\xff>\xfd\xf6\x83\xbf\xc1Z\x8a\x12\x83nj}\xa5\r\xfd\x0e\xfb'
        b'\xb1\x90\xa1\x81]\x80\xdf\xf8\xba\xc0CK+\x13N\xf1V\xb9\xeb>\xdb\xc1p\x03\x8c\t\x01\xc0\xbb\x81\xae&\x01_%ZJ\xa7\r\x0e"\xac\xdc+gR\x94G\xa0\x8b\\\xae\x15\x81z\xa9\x1f\xb4\xa6R\x14\x01\xa1\x14'
        b"D\xd7Q\xe84\x8e\xa5\x8b\x11F\x19o\x18M\xf7\x8e\xfd\xd7\xb3\xd0x%4\x9a\xa5'\x0b\x84\xbd\xefh\xa70{\xeb\x1b\xc7\xaf\x85\xf6W\xb2\xc6\xd4\xd3\xfd\x05K\xd0\xf9\xd1\x82\t\xf3F\t\xdd\rdL\x8a\x92=\xbf"
        b'i\x9cd\x12*\x9b\xdb\x19O2\x0f\xbaX\x8dG~\xd8\xbc!\x88_\xce\xc0[\xf7A?\xcf}\x87;\x96\x9e\n\xa2\x04P"\xc3\x08\xa4\x0c\xb5\xc28h\x08j~~\x0c\xbe\xdcX\x9a<5\xa6\xba\xaa\x9c\x15\xb4}'
        b'q\xfae\x01\x8e\xb6\x83\xee\x88\xe1\xd3B\x0f\xa0U~\xba\xca\x14\xd3\x8f\xef\xf3m\xc3\xda\x8eb\x04\xd7[\x8c,8\xc2\xa1y\xad\x15\xf5%Hz\x89Z\xf6\x02\x10\r\xb4\xd10Wd\x00A\xb0\x164\x8bRSR\xe6'
        b'h\xe2\xc1k|W<Q\xd1\x95q\xc8\x9d\x1c\x95FN\xcf\x03y\x0f\x970Qz\xeb\xae96}\xa9\x1a50;-m\xe45[\xbd0S\xf4\x95 \xaa\xa5y\x9c\xce\xb3o\x08C&qP\xa4\xbb\xcc\x0c\xfb3'
        b'\xc8\x85_M\xdbN\xa9\xa0\xe59\xe2\xf2\x04o(3\xf8\x8a\xca\xbd\xbb\xfe\xbc\xb8\xb5>\xfb\x1e\xcdGh#$02\xbc\xad#i2<`\xc8\xe1\x83\xde\xd3\xc8\xdd\x17\xd2\xcf\x81!\x1b\xfd\xe2\x9bV\x00"\x1bo\xb4'
        b'+\x13h\xecK\\\xf4\xa0\x8a\xd7d\x82\x9a\xcf\x8a\xa4\x13\xab\x13\x17\x94\x8c\x9caD\xf8\xb3\xba\x16\xe9\x14RGj5\x9f\xbb\x9f\xb9\xd9u\x13\xe6\xb1\xe0$\xf6X%&\xf2P\xd0\x9f\x00\xbc27\xfcVR-5\xf5'
        b'\xf0\xd4\xdbs\xf5\xea\xffW_m\xaf\xbfo\x8a\x7f\x80_\x92\x9d[x\x8a\xd562m@\xf30\x97\xf7\xcd\x12\x12\xa3\xa4\xe6ex\xee\x90\x94\xac\x92\xa3I\xd4k%M:P\x07kf\xbd3\xa1\xfd\x8f\x81/\x8b<'
        b'\xba\x8d\xf9;\xb4\xafg\xbc\xe7r\xd1?\x9197\x0c\xd4\xfcI\x1bh2\xc0\xd1\xe9\x8f\xf8\x80R\xca\xa7\xfb\xd08!\x03\x07\xc6\xb9\x1a_ \xa6u/\x85\x0f\xda&"f\x910\xd5\xd5B\xe9\xb7\x0e\xc9\x9e\x8f\xbba'
        b'\xdeK \x7f\x1b\x8c\xb1\xbbo6F\xb7\x1b\x86Z\xad\x08Z\xbc*G\xd5\xad^\x12\x022\x1f\xb8lY\xae\x9c\xb3c\xe5\x04\x1a4\x8c\x91\x1b\xcb\r\x9a\xed\xfe\x97\xf6\xadjzgv\x8c\x87\x93\xf0\x13\xd3C\x16\xbf\xa0'
        b'\xc5,\xc4P\xca\xa3>J\xdd\x1d-\xf4`\x19\xf6\x1c6*vY*Nl\xa5v\x83h9\x8c\x9d\xf11\x17;\x169x`\xb0\x16Z\x11\xb5\xe4q6x\xfc^\x07\xb1x;\xf4-d\xdc\xf7-\x07\x83\xa8\xe2m'
        b'J2\x96\x18j\x07N\xd8\x8e?\xd9\xf7:\xdfc\xde\x8fi*\x1a)#%\xe0\xc2\xc9\xec\x06\xfa#\x9c\xf8\xc9!\xcf\x91J\xeb\xa7\r\x0e\x1e\xdd\xb0c\xcf"\xb9\xb2\x9d\x9a\x92[\x81\x94i\xac\xef\xb2\xf1\\R\x8c\xa1'
        b"nv\xc8*\xadWY1\x0e\xaf\x86\xb1V\xef\x1e\xa6'\x8bx\x03\xf2Dt\x95\x19U\x12I\xb7.N\xee\x19\x9c0\xca\xe1\t~\xb9\xb9\xb4\xf3\x05k\x08\xc4\x1c\xfaEya\x93\xc0\xcf0\x7f\xf5M\xee*W\xbe\xef"
        b'\x08KG\xd3\xb9\xddm\xd0\xcf\xf0Y\x1b\x17\xdae\xcf\x17\xb4\xf4ka\xd4\xcci\x17\xd1a\n\xa4\xc2\x91\x8d\x864\xd0&\x1c\xc1f\xa2\x0f\xc5d=\x07@<\x10md\xf4\xe1\xce:yKqD\xb4\x03@,R\xf8'
        b'_q\xbd\xb17\x95\xa5\x19\xc2FO\x8a\x07\xa7\x9c\xabf\xc2|<:S\xdc!\xa9w4\xcc\x02\xb6\xad\xd7\x00\x07\xa5`\xe1\xcf\x99\xf3,\x97\xd0\xb0\xdcQ\t\x97\x80\xaf%?\xa6\x19n3k\xbf\xae\xe7\x08\xb7qk'
        b'\x12izx\xc6hc+\xf9\xad\x0e\xc4\xd5;\xb9\x80m\xcb\xac\x06g{\x11\xaf\x07\xfc\xe2\xd1d\xad\xf1\x00\x02\xb33K\xf4\xf5fs\xeav\xab\xc6\x9a\x99\xdaA\xed:k\x8a\t\xd8\xff\xb6\x02\x04\xbd\xda\xa9\x96\x81@'
        b'd\x1d\xca\x9f\xcc\xbd\xda`\x8eM\xda"\xc2DCZkN\x1c\xbe\x87\xcfc\x9b\xed\xfb\xd3\x9a\xea\xc5O!\x17%yL\xb7\xf5\xd9\xbd\xd2L\x8ay \xc6\xe0\xb1\x01\xdf\x99\x17(;`a\xde\x7f=~\xfe\xb3\xa7\xa7'
        b'e\xab\xb9\xa3\xe3\xa1\xfa,H\xc0\xaa\x0b\xd1Z\xf9w3\x93yXk\x83\x8c\xe1\x03\xe4)\xbcg\xf8\xd2D\x85\xd2\n]\x06JU\xdc:6m8J\xc7@+\xe9j\xd0\xf4\xd2\xe1m\x18\xd4tVd\xda/\xbf\x82'
        b'wR\x0e\x16\xc9\x9d\xdb\xcc\x1f\x17\x97|\x97o\xa8\x11^#6"\xd3\x92\x1a\xbee<\x01H{\x8e\xadv@;L\xf4\xfe|k\xb4\x90\xe9\x907\x04J\xa1c\xfe"\x16\xe3\xd6\x9f\x11\x08\x88r\xfd\x91\xc1\x1bh\xd0'
        b"\x15P\xc5/\x03^'\xc0\xce\xce\xe4\xea2\x1f\xea\xb7\xeebB\xe9\xf4f\xe5\xc8t\x19\x1b#\x12\xec7\x80bf.\x07\x10`\xb5\x12h\x11\x0f\x81@\xef9\xa8\nw0f\x1e%\r\xe0\x05\xa8\xea+\xfc(\xcb\xbe"
        b'Q\xf4\xd9z\x06\xee\xd7l\x15\xf9Kh\xc9\xcf\x96q\xb1\x88[\xe00\x90\x0c\xc6z-\xaf \x13\xadC\x8b\xb7\x90?D>\xd0^\x90\xbb%\x14!R6\xdbw\x97\xda\x00F\x1c\xaf\xb6\x88.\xdd_\xb0\xd0\r_8'
        b'\xee\xb9\xbf\x84\xde\xd761\x83<\x80\x88\xb0^|\x8d$\xb1O-m\xc3\x1f\xde\x9b\xac\x1f,\xeb\xab\x87\xa0\xa1\x13(\xdc\xf3\xf4\xb4\x8al\xc1\x19\xe0\xf0\xe4\x8e\xdeu\x87\xbd\xa6\xb2\xec\x11rq(\xf7=\xfc\xc5\xe0!'
        b'\xd4\xaa&\x84\xb9\xee\xe1&\x8f)\x87g\xa5\x1f\xb0\x83\xac\xb8\x07Y\x15\xad\x82\xee\x95\xd0\\c\xd1\xfe\xa2I\xa4R\x9b\xf6]\x1bW\xcc\x88\xe1M\xf2\x89ulU\xf34\x1c\xa2i\xa0\xd21\\Lm\xb7\x9a\xc7\xc9\xb7'
        b"\x1a*l^\x85\x05\xda\x84\xb2\x1cU\xd1I\xba\x8bA\xeb\xfc\xcb(\xb6<\n\xe1P\xa4\xd2Q~\x11\x9d\xe3\xb1\xb3'\xd2xw\xfa\xc5!\xf5\xa3\xd9\xffu\x01\x1b\x80^\x82R\xf7\t\xc6.\xd7\x01\x9e\xe1\xa0\x87\x18\x12"
        b'\x9c`\xc3\xf3|\x8f\xa2l\x9e=\x8d\x06\\\xb6G\x83\x13W\xd3<\x12 \n*M`\xad\x9c\x10\xac\x1cDL7\xe1\xd3+\xef\x9c>\xbb@\xdc\xc5;*\x82\x1c\xc1\xd9\xf9+=W\xd2\x1f\xa2E\xb8\xa2\xf8"^\xa2'
        b'Jy\x13\xda2\x85\xbb\xaf\x07B\x1d\x1f*~6\x12\xc2>\x95\xb2Ux\x13\xac5P\xfb\x06\xaf9\xeaF\xa1d\xd1ir7\xee\xcfX\xe6\x05\xd8\xc3\xaa\xeaZ\xbc\x95V\x85\x8ce\xec\xe8\\\x1dz\xd8\x1c![J'
        b'\xd5\xef\xa7\xef\'\x94\x04\x1bK\x95\xe3\xc0\xb3\xe4\xa1\x90x\xcd\xb5\x18\xa1^\xb0V\x15P\xf9\x88\x9dX\x85\xb9O3\x9d\xe95l\x0b\xb7\xc2\x9a\x13V\x9c\x9a\xc9\xf0\x99\xcc\xff\xef\x8d>o"\xde\xcc\xcbO60\xea\xe4'
        b'.!/\xfa\x18\xaf\xf3\x96\xde\xdb\xda(\x82\xd0\x81\xcf\x89[:9"\x80\xb8\xd2\xb2\xa6S\xd4\x16\xc3\x93\x91\xed\x18\xee\x96\xe1i\n\xaf\x12:F\xb12\x95\xd0\x10\x8eQ\xf95\xf7/Cz\xab\x12-\xc1h=\xe7\xa5'
        b'\xce\x9b$\xc4\xbb\xe0\x19\xf5\x81\x07\x92\n\x87\x08\x87\x19\x91=R1_\xb0\xf3\xbe\xe1\xe8&\xe1w1\xbbh\xcd\xc5\x0c\x9a\xb2\x00Y\xea\xe3\xc8\xc3\x9a\xe3\xe8\xdct2\xd3D/\x85\xb1\xa7\x1b\xce\x8e\xd8w\xbb\x1e\xe2X'
        b'&\xd1}\xe8E\xdf\xa4\xff\x17\x96\x88\xbb\xb0\xef\x8e\x8aiu\xbf@\xb5\xca\xe1\x06 Mk\xa8\xb6\xae\xa9\xfb]K\x85_\xaao;\x9f(O\xcb\xd4\x0e\xbb\x04\xa1~\x05\xd5\x86\x01\xaf\xf4u-\xa4\x13\x82dw";'
        b'\xe3,=\x10*\x1ev\xe0\xab\xae\x1f\x9fZ\x04Y\xf1gi\xa0\xa5\xeff\x1e\xccjVCa:\x13\xdeF6\t\x0b\xa70H6\xd3%C\xfdvx*\xdd\x17\xbcsN7\xb8\x08I\xe9\xd2\xcd\xa6\x94\x95J\xb0\xd3'
        b'ix\x07\xb7\x8b\x01\x1e \x07\x9a\xa4\xcar\x0fr\x10d\xc0[\x06\xbc\n\xfbUx<\xe7\xea\x05\xe8I\xaclLX5\xd6\x00?\x1c\x91\x9c]\x0e\xab/\xd9\xf8>\xd5<G\xf1\xaca\xeb|\xc0\x0b\xf6\xfe\x95\x15\x13'
        b'\x9c\xeb\xd2b\xe5\x1a\xa7\xe5F\x96\xa4\xbb\x8b<\xcf\xda\xdbb\x1d\xd4g\xd7o\x92\xdc\xce\xf3NK\x8b%\x02B\xd2D\x7fQ\x9c\x03R\x90\x02\xc35\xfb\x8d\xd3\x8b_\x99\xa0\x90F\xe5z\xfb&\xe4w\xfc\x8fp,\xac'
        b'\x18\x97\x8a\x05\xfd\xc7\xed\xa7\x05\xe9\xed\x82\x9d\xbe\xce\x17\xdf\xbd+6\x07\x82~;Op\xa9>\xb8\x8e \x7f?&7G }\x81+\x9f#\xb5I\x15\xf2\x1b\xb5.\xb8x\xd1)\xd1fds\xe0\x0eTO\xa1\xd6\x8c'
        b'\x87\x90z(r\x1du\x00Mcr\xafR\xf17>"y\xa3.6`\x85\x8b\x10\x07?qD}\xdd\n\xa7U)\x92\xf0\xe9?C\x8d\xaa\xc2\xf0\x1f\xab\x9b\xb7\x17\xe1\xaf\xab\xf3\xc7\xf8oT\xef\xd6\x03\x0e}\x02\xdf'
        b"\x84\xc2\xfe\xa8\x9a\n'U\xc27\xe7fO#\x02\xd2\xf8]\x94\xd7\x83%n\xf9\xf8\xfb8\xe0\x11\x89I\x07\xc2\xf3e\x070X\xc0C\xeb\xb1o\xea\xf8f\xa0U\x1d\x8b\xce5sAy(\x8d\x03Bq\xd1(@L"
        b'\xb9\xf7\xd6\x8d\x81\xa9\x87\xbe\x18\x86%\r}B\xcd[7\xa4\xe8\x16* 8\t\xea\x0c \xae\xe5!\xac*QO\x84tv\x00G\xb8V\xd3\xa1V<\x9a\xf3\xcc\x83EE\x89\xa8\x8e\xea\xd1r\xd3joIs#u'
        b'\xbb\r\xa9\xf0t*\xffC\x06\xe0\xd8Q\xbd\x8c\xd4\x00\x9d\xc7Y\x08\x97\x95\xdch\x1e\xce\xb3\x0e\x91\xf4\x83\x11\xa6\x13%xi\x97\xbe\xcb\xe8@\xacF\xc8\\\xae3\xe7\xfc\xb2\xc78\x98W\xf9b\xc5\x18\xac\n\x0e\x93\xf5'
        b'\x18\x0c\xf4\x7f\xbb#\x8cj\x1a\xac\x03\x1e\xff\x9c\x8a6\x91\xc4\xaa\x92\xb3\xac\x02\xcf\xff\x1do\xfb\xb2S\xf4c\t\xb6\x95b?\xd0\xd2DA\xe0\t\x05\xab8wH;\x8fh\x94\xd5>\x87Me(\xdf\xaa3\x8cn.'
        b'\xe3\xdfp\xafy\x8cs\x1d\xdfz\x8f.\x94\xd8\xd8\x9d/\xba\x8f\xfc\x01\x12W\xfc\x97\x1d\xea\xc9\x89\x0b\x17\x87\xef\xe7\xa6\x14u\x0cfE\x19\xba\xd4\xb2B\xb4\xcf\xf16\xe42\x0e\xe8\xa2\xa5\xdfh\xc9\xbc\x94\xa8fS\x14'
        b"\xed\xaf\x19\xe8\xd2\x03F\xe6z\xcb\x85\xdb\xe9\xc3\xd2\xc1\xd6\xa5\x93Yi\xaf\x9d\xb9\xdb\x0e2[\x06\x13/\x07\x1a\xd0Z\x84F\xfd\x03\xe9\x04\x8f\x9e\xd0:k*\x00'}\x0f\xf1\x07\xe3\x88\xd8\xd4\x06\xd6\x94\xae\xf5\xd1\xb9"
        b"\xca\x80_\x183hT\xae@N\x0c\x9bXrcrx\xd9\xa6\xa9|\x02\xbe\xea\x18\xaa\x1b\xe4\xa0\xc3]i\xb3\x1d}\x94\xbf\x99SK\\}U#\x14i4\xb4\xa1\xa5\xb6\xe1\xfe\xcd\xd1i\xf7\xbf\x0c\x82\x11'[\xc4"
        b"\rO\xcb\xd0ij\xf4\x890\x9b\xc8\x0f\xdc'\xfa\xd3\x01AAf\xff%q\xf8#\xdf4n\x9d+\xe1n\xd6\x7f\xb6\x0c\x98\x1e\xcdF\xdd\x94\xcc \x86;\xc2\xafJN\xee\x83a\xbc\x1d\x10\xbai\xbb\x93vP\xdf\xb2"
        b'\x92\xb8\xc3{Q\xfa\x81b\x8d;\xcf\xf7\'\x8d\x9am\x1e\x0b\xaa\xc74\x92o":\x93\x01$\x86\x93*\x95\xe9\xf3/4z4G\rK\x07v\xb90K\x17%\x05\xbf\x9b\xbdKg\xd6\x0ft\\\x81=\xc8vzt'
        b'\xf2w)\x89}h\x9fs\xc6/\xe0\x9a\xcc\xe6\xcb\xc6L}j~\xfe\xea\x7f\x97\x9d\x18\x1e\xe8\x82\xd9\xe8]\xbb\x94zt9\xc1\xc5\xae\xa0\x81\xa8\rJr\xf6{\xda\x18\xbf\x97@\x89\xa5\xf4/Xyt\xab\x1d\xf0\x11'
        b'\xc4\xbdHV\x0e\xb9\x91\xf7>)]\x87\xd4\xa4\x0b\xb6b+?\xe5\x87\x8e\xa232\x15\x8c\xd7\xf1\xbe\xc9R\xc9a\r\x9e\x85\x89#\x96\xaa3(\xcdcq\xba\xb3\x83\xe2[\xc0\xbb\x05\x10g\\\xd3uH\xc0\xd9\xba\x02'
        b'(\xbc5\xe8\xa1\xad\xc6\x10\xd3\xee6\xf0\xbf\xad\xea$\x0e\x82\xc5\x16\xe3x\x01+-\xe5c\xe2\xe9@\x832\x13\x1a\x17>\x03\xab\xba5\xac\xfc|\x8d\xa6\x90P\xfdH\x04\xdb;\xf9\xa8@?j\xcb}\x99\x1dY\xa9\x9d'
        b'[k\xc6\xf2\xb5m\x13O\xe3Y\xab(8\xee\xb7o\x99m\xc7ni\x8d\xec\x0f\xe8\x15k\xd9\x0c\x8e\xc0\xb4\xc3g?\xb7\x92\xea8\xdf\x81\xc2\x07z\x18\xd9\x0b\xf2\xdeS\x0b\xd3o\xbb}y\xad2\x95\xa4.\xa0J$'
        b'] }b\xfd\xbfA\xc7e\x00\x94\x15\xedm[B\x1b\xc9\xf0\xf4\x1a[L\xc0z\xfa\x927\xe1\xc1\x01\x84\xb5\xd7\x1b\xb8\xb4[\xf4\x8eW\xcfyh/<\xc7v\x17!\x0c\xba:\xb7\xb3\xaeWW\xa7I\xae\xb4\xf7P'
        b'_\xd6\x1bv\x04\xbe\xb4g\xf6\xf0`>_\xe9"\x96;|Q\x99\xc6\x93I\x96\x8b=\x85\x86Ao\xd2$\xe7j\x9a\xb8\x9akz<\x02n\xc2\xc7zC\xe0\x1b\xadw\xc4N\x90T\xb5$\t\x96\x1dRJ\xfb\xb7#'
        b'%\x10\xde)(1\xef\x81F\xab\xbb\xcflsp\x02\xaa\x17<\xc0M\xaf\x00]k\xae\xd1b\xa3\xde\xf9\x06+^m\x95\x94\x8fA\x07\x9b\x07T\xdb\x9b\xb2A\x83\xed\xc4\xb6\x06\x85\x8fz|&\x0eA\x1b<\x90?<'
        b'\xe4\\T\x82\x10\xd0\xbf\xff\x06?\xcf"\xc5.\xb6\xa8J\x87N\xe0\x91\x994g\xc9\xd6\x90a\xf2j\x15U\x88\xd6w\xa2\x89\xd9\x16\'\xff\x90\xec\xd5\x1c\x9f\xc1\xc1\xfbJ\x06^)N\x95\x03d\rk\x1a\x15\xbf\xf0\xe9'
        b'\xf6\x18\x18\xe5\xee\xdbp\x93\xa4\xb5\xd4\xaf\xac}\xff+DK\xb0\xd9\x8bw\xe6\xc9]\xcaX(\x7f"\xc3\x8dd\xafV@\x975\xa0Rqv\x85\xe5\xce\xbe\xea{0\x16\x91\xb2\xd3\x08\x98\xd2\x97\xcd=\x8eODl\x8f'
        b"\xf5\xb7\xf6XHd\x92\xa7\r\x1a\nj\xc3\xdb\x81\xb7Y\xf4'\xac/\xaaVuU\x02\xf68\x98\r\xe6\xa5)W\x84\x08\x08\xbe\xc3\xf2Dwc\xed\xf0\x12\xba\x08\x10\xfc\x94\x10\x91\xf9'Y\x0bv\xdc\xf6\xe4\x83z{"
        b'G\xa7\xdc\xe1\xae\xc6\xdfpmn\x9fZk\xce\xd1\xbc\xc5K\xfa\x9f\xce]\x86\x1b\xbd\x02\xf2wM\xbb\xd5\xa1\x84)K(\x04\xda\x0c\xde\xef\xc0\xa5\xcc\x15\xbd\x1aI?4\x81\x00`\x10\xe1KB|g\x0e:\t\xee\x99'
        b'\xd6\xe7\xbf=tB\x1d\xd5\xfbx\xe6g\x05\x19\xc3K&\xd6\xff\x80\x10%\xae^\xd9\x86\x110\x94\x8b\xa2\xc2\x85%Y\xcf\xe9\xe4ODu\xb3\x01+\x04\x05d\x1e\xfb\xc6\x06\xd5\x92L{\x8e*\n\x19\xec\r\xef\xd0\n'
        b'crO[\xb6\xa7\n\x85A\x83\xca\xaf$LS\x9e\xcf`\x80\x1bb\xbd\x02)w\xf0\xbf]-\xd1\xa3\x0f1U\xbb\xd2\xdbaaa\xd6<H\xf4\x93\xb5\xb5\x912Iiz6\x93GoR\x10\xbait\x82\x17\xb3'
        b'\xb6\x11\x8fNAK\xdbeD\x1a \xe1Z\xbc\xb8\xfa\x9dL\x00l\xef\xcc\xa6?)lC\x96\x06Z\xbd\x8f\xb6\xfc\x0b\t\xb28\x19\xdfRM\xf0\x18\xb2\xdb\xf1U{\xc2@\xb9\x12gn\x15%\xca\x98.\xd5\xf7\xf6\xdc'
        b'\xa4\xf6\xba\xc1\x94\x9f\xe7\xbb\x86l)\x01\x8d\x07\x1e*\x17\xb6\xb1w=`\xdb\xb2\x1c\xcf\xd8\x9f\xfb\'\xc2\xfd\xf3\\\xc2"mi5\n\n\xa8\'\xf1\xc8MC{\xc1v\xd28\xf0J<\xbb\r)m@K\x9f\xdb\x01'
        b"=\x84<Uz\x17\xc88\xdcY\xcdQ#*\xf0'`\x85\xf2\x96KQ8\xea\xa7Z*\x97\x8b\x89\xe2T=\x8d\x9b\x16\xc5}\xfb{\x12#-l\xff\xb5\xc8\xdaQ\xf86>A\x01\xf3\xa2j\x89r\xc5\xe1\xba9\xf4"
        b'x\x13\r\x1a\x17\xb95S4\xd6f\xe1\xcb \xe8!\xfe\xff\x07(2E[\x83lI\x7f\x87\xd5]\xeeQNH\xaft\xe2\x88\x98\x0b\xd8\xb5\xc7\xf2J\xad\xa6\xb3qbv\xae!\xe1\xa5\xb3\r\xb4\x92\xc1\xac\xd5\xc4\xd0'
        b'\xb79\xcd\x1cc\x1b\xbef\x807\x18\xf1\xb8\xec\xe9\xc4|\x85\xeb\x15\xcb{\xda\xa3\xf9\xf5\x88?\xc2n\xa6\x99\xf8\x896\x01\xfaeV\xd2h\xb8\xe1\xfb\xb8\x8a`?\xd7\x15\x16\x02L$\xb8\xbe\xb1j=HN\x1e\xff\x1b'
        b'\xa26s\xd0&\xf2]\x86F>\x02d\x87|\xee\xd6\x1bect\x15\xe6~Y \xf8\x98\xb71\x95\xbd\xae\xaav\xc8\xe6J1/\x96\xfc0d\xc4\xd2(\nF\xcc\xbf\xc1\xe6y\x00\x00\x00R\xec\xb3\x7fP`1G'
        b'\x02P-*a\x18\x84\xfb\x81\xed\xe6\x9e]|mu\x102\xbc\xb6\xd5%*\xd42Q\x14\xd9uLk\xfb\xf1\x14\x06a"\t\xa2\xa0\x98Q\xed?O\xf1\xfc\xe3\xdf\x13\xc60u\xe7\xd2J\xbc\x80\x1d\xbe\x18\xa3ve'
        b'\x0b\x8c\xdc\x96.!\xa4\x8b\xb0&\xc80\xa2x\x84{\xb3\xd8\xce@p\xbb\xea\x17G\xd9\x15\x98P\xfeF\xa9\xe6\t\xdb2\x98\xc9\xc5,\xdd\x8b\x00\xd1\x85qg/B\xc2\x85wW\xc9\xa9T\x02\x11\x97\x8a\xea\xcf\x06d'
        b'M\xf6_\xa89S\x11:\xf8j\xd8Z\x0bE(Y\xa8\x91\xc2\x8d \xd45\x938eJ\n\xe9\xd8\xb2\xaf\xf6\xf0\xc0\xf2\xa6\x8bJt:\xe8\x99\xdc\\\x1c\xa5\xae\xb7\xac\xb7\x0bmIy\n\x1f\x00\xe0\x7f\xde\xc5\xc2\xaa'
        b'\xc7\x83\xc6[Iw\xb5n\xc0\t\x9fc\xd8\x9d`\x8d\xf3B\xba=*zx&2\xec26\x9a9\x03\x89d\xdd\xd9\\\xa5\xc5Q\xfd\xa7\xac\xad\x7fk\xc24kK\x84\x82\xd9\xd0\x0c\n\xd4\xc8*\xcfR\xe6G\xaa\xf0'
        b"t~p\xa1\x83)]U\xa7\xa8\t\xb0\xeb\xe3\xe1\xc4\x1d\x8c\xf6\xe6\xb4\xa1\xe6\x080\xcd\x067=\xf8j\xf0\xe5#d\xb7\x14,9\x900r\xd4\xf7'a\xc2\x89G8\x94<\xca~\xc1\xdbhg\x7f\x8d!\xf7\xbf<"
        b"\x9c'\xe1K]\xde\x82\xaf\xa3B\x08S\xaby\xa2\xe8\x0fS\x9f\x9a$t\x99\xe5P\xca\xb6\x8c,\xc1\xed/m\xc4\xc6;#~\xdc\x1a|\xfc0$\xc1\xbf\x8a\xf9\xe9K\x170G\xf3\xe9\x8a\xaa\xb3@`d\xc5f\xf9"
        b'\x14\xa4l\x1b)m\xa9\xa0\xcbup/\x15\x01\x98Wu)\xeb\x0f\x9c\xa0w1-\r;\xbce\x94\x81\xf5>p\x1d(\xf3\xf7T\xcbb0w/\x02\xc6\xf4U\xae\xf2\xf7\xe9o\xa08Z\xde[\x15\xf69\x17\x0b\x08'
        b'\x01&\xa7\xff<\x0c\x14\x02\xc4 f\xac\x14\x1f\xcf"\xd9\xed[Ig\x80m\x84\xa2\x9d\x91\xadQ\xe5\x0fJ\x1d-Ni\xfa\x06\xe2\t\xacD\xd3\xc6b\xbe\xed\x8e\xb9\x00\xd59x\xf3;B\x95\x11q\x00\x00\xf2\xaa\xff'
        b"4\xe3\xc5\x0e\x99eV\xe5\x17\xbf%\x8d\xad%u\x87'\xb3\xed\xe4,\x1d\xf3sw:\x9fk\xda\xd5e\xdd\x9e\x1a\x84\x05;\xd3\xe3\xbf\x88bG\x08AU\xa8\x02\xaa\xcf_(@\xe5\xf3\xa5\x0b\x9bn\x8b\xcc\x9cr\xc9"
        b'\xf9\x8b\xdf\x06I\xd8\x1e!\x8eF\x82\x88\x15\xe8J\xc2\xcbNjHgx\x00d\xec3\x1f,\x84\xcd\xac\xa5`\xb7\x1f]\r\x92\xd6\x7f\x0ff\xaa\x0cJ\xf7\x839\x17b+\x8eje].)\xac\xb1\xce\x7f-O\xb7'
        b"O\xc8Fe\xb0LBR\xd0\x16\xdcR\xeaIC\x0f])\x83\xc6\xe57\xe1\xbe\xb3\x83l\xd8\xce\xbe\xd5@\x04+\xdc!\x1e\xd9\xa0\xc4\x1d\xb6\x15\xb0\xce\xaf\xf0.}\xe8\x1a\x19\xdfv\xaa\xb44'\x92\x87\xcf\x06r_"
        b'\xc3V<\xb7UL<\x88\xac\x12\xad\xad\xac,k\xcfu\x1d\xd3\xa6[1\x07\xc2\x13\xf3\xb6\xb2\x00\x93\x94$\x88\xd9\xcd\xee\x93\x893\xc2\xee.\xab\x8d\xde^\x9fQ\xdcSA\xa0\xd1\xf1L\xd1\xba|\xa9\x16\xa8b\xc0\x9a'
        b"\xb4C\x9d\x15ZOaH\xde%\xcb\\$.m)C\xbf\x970\xa8\xc7\x03\x1a5\xcb\x04\xc3\t6\xe97\xd2\x17?\xf5\xdeX6\x8eb\x9a\xaa\xdd\xa7\xf5\xc6z\xbc\x17\xefv'\xa57\x9b\x82/f\x13=Y/L"
        b'\x1f\xad\x81~Z\x14b\xd9\x84AA\xa6\xf8\x1f\x99\x8fN\xebo~\xfa\xe7B\xfb\xae\x05\xc7\xfa\x99M\x13<\xd5\xd0\xde\x9cR\x00\x8b\x972h\x0b\x90\x94\x0c\x1b\x1d\x9e\xe7\xdfV\x81+\xd1*\xf2`\xc0\x91\x12L\x81\xdc'
        b'6H_l\x11\xc9\xe4\x82l\n(\xde\x06L\x842\xb1\xf0F\xf2\x95)\xaa\x1b\xa0\xf6\x07Zt`\xb9\x9f\x86\xce\xfc\x1agy\x88\xd7j\xac}\xa6\x9d\xcb\xaaCy\x9c\x11\xfe\xb5.\x145\xbb\x12\xa2\xa6\xed\xd9\xe5-'
        b'\xac\xde\xdd\xa4\x97\xe9@.?Md\xd7xgcp\xa6L\x7f\xc9\x02\xf6F\x00\xd9N\x90\xf5\xda\x8eb\x1dL\xdd\xc1\xbf\x89\xe0\x07\x96m[\xbb\x80T\x8c\xf9n`\xa7\xa0\x0e\xbf/\xe6_`3X&V\xfc\x9c$'
        b'\x04\xf7$\x87\xe8\x19I5b[d:>\x85[\x9e>W\xf3\xab\xff\xbd5\xf3z\x84 r\x1c\xaaZ|\x05f\x99\xe3zHYh\xdaD\xeejA\xe8\x9c~x\x93T\xd2\xfd\x9d\xfbD\x18\xc3\x0c\x84L*\xff\xa8'
        b'\xa5V\xf4\xe3I+966\x11\x88\xfc\xb3ku\x8d\xb9/\x80X\xe4n\xb0\xadPN(A9\xf6C\xe3Y\r\xe6\xf1\xbd\x92\xb1L$\x8c\xd4;l_R5\xa1B\x87\xfc\xcb?\xc7\xc9S~\xe9\x04\x86\xed-\x02'
        b'\x97\x96h\x18@\xe0\x1a\xb0qIM]\xfc\xbeY\xe8xj\xc7\xc7p\x87bTF\xcee\xcebr4\xdf\xe7Uz\x88\xd3\x1f.\xfc\xce&\xadJR\x144\xd7\xf0E\xe3\xd5\xa2\xa5\x1d\xed^\xde7\xed\x1b`\xaf\xd7'
        b'\x9d\xa2\x08H>\xb30\x7f$\xca\x85\xaa>\xe1r\xbd|\x08j!\x1b8M\xe4i\x1f\xc5\xd4\xbd\x14\x9e\x99\xe8\x83\xf7S\xd6\xe3\xa0^\xba\xbd!\x16\xa62\xd6\xe5\xca\x81;\x8a\xea\x85\x8c\xf2\xc0\xeb\xd0\t\xdc\xa5F\xd6'
        b'\xf1\x0c%\xcb[4\x97r\x18\xd4A\x88D\x13\xdf\xbeQ6\x0e\xb38\x0fL\xe3:LvrR\x83R\x04\xe6\x0cV\xe9\x01\x00\x00\x00N)\x04Z\x0b__pyarmor__\xda\x0cRuntim'
        b'eError\xda\x08__name__\xda\x08__file__\xa9\x00r\x05\x00\x00\x00r\x05\x00\x00\x00\xfa\x16<frozen fintech.swift>\xda\x08'
        b'<module>\x01\x00\x00\x00s\x04\x00\x00\x00\n\x01\x14\x01'
    ))
